# coding: utf-8

"""
    Selling Partner API for Finances

    The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class FinancialEvents(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'shipment_event_list': 'ShipmentEventList',
        'refund_event_list': 'ShipmentEventList',
        'guarantee_claim_event_list': 'ShipmentEventList',
        'chargeback_event_list': 'ShipmentEventList',
        'pay_with_amazon_event_list': 'PayWithAmazonEventList',
        'service_provider_credit_event_list': 'SolutionProviderCreditEventList',
        'retrocharge_event_list': 'RetrochargeEventList',
        'rental_transaction_event_list': 'RentalTransactionEventList',
        'product_ads_payment_event_list': 'ProductAdsPaymentEventList',
        'service_fee_event_list': 'ServiceFeeEventList',
        'seller_deal_payment_event_list': 'SellerDealPaymentEventList',
        'debt_recovery_event_list': 'DebtRecoveryEventList',
        'loan_servicing_event_list': 'LoanServicingEventList',
        'adjustment_event_list': 'AdjustmentEventList',
        'safet_reimbursement_event_list': 'SAFETReimbursementEventList',
        'seller_review_enrollment_payment_event_list': 'SellerReviewEnrollmentPaymentEventList',
        'fba_liquidation_event_list': 'FBALiquidationEventList',
        'coupon_payment_event_list': 'CouponPaymentEventList',
        'imaging_services_fee_event_list': 'ImagingServicesFeeEventList',
        'network_commingling_transaction_event_list': 'NetworkComminglingTransactionEventList',
        'affordability_expense_event_list': 'AffordabilityExpenseEventList',
        'affordability_expense_reversal_event_list': 'AffordabilityExpenseEventList'
    }

    attribute_map = {
        'shipment_event_list': 'ShipmentEventList',
        'refund_event_list': 'RefundEventList',
        'guarantee_claim_event_list': 'GuaranteeClaimEventList',
        'chargeback_event_list': 'ChargebackEventList',
        'pay_with_amazon_event_list': 'PayWithAmazonEventList',
        'service_provider_credit_event_list': 'ServiceProviderCreditEventList',
        'retrocharge_event_list': 'RetrochargeEventList',
        'rental_transaction_event_list': 'RentalTransactionEventList',
        'product_ads_payment_event_list': 'ProductAdsPaymentEventList',
        'service_fee_event_list': 'ServiceFeeEventList',
        'seller_deal_payment_event_list': 'SellerDealPaymentEventList',
        'debt_recovery_event_list': 'DebtRecoveryEventList',
        'loan_servicing_event_list': 'LoanServicingEventList',
        'adjustment_event_list': 'AdjustmentEventList',
        'safet_reimbursement_event_list': 'SAFETReimbursementEventList',
        'seller_review_enrollment_payment_event_list': 'SellerReviewEnrollmentPaymentEventList',
        'fba_liquidation_event_list': 'FBALiquidationEventList',
        'coupon_payment_event_list': 'CouponPaymentEventList',
        'imaging_services_fee_event_list': 'ImagingServicesFeeEventList',
        'network_commingling_transaction_event_list': 'NetworkComminglingTransactionEventList',
        'affordability_expense_event_list': 'AffordabilityExpenseEventList',
        'affordability_expense_reversal_event_list': 'AffordabilityExpenseReversalEventList'
    }

    def __init__(self, shipment_event_list=None, refund_event_list=None, guarantee_claim_event_list=None, chargeback_event_list=None, pay_with_amazon_event_list=None, service_provider_credit_event_list=None, retrocharge_event_list=None, rental_transaction_event_list=None, product_ads_payment_event_list=None, service_fee_event_list=None, seller_deal_payment_event_list=None, debt_recovery_event_list=None, loan_servicing_event_list=None, adjustment_event_list=None, safet_reimbursement_event_list=None, seller_review_enrollment_payment_event_list=None, fba_liquidation_event_list=None, coupon_payment_event_list=None, imaging_services_fee_event_list=None, network_commingling_transaction_event_list=None, affordability_expense_event_list=None, affordability_expense_reversal_event_list=None):  # noqa: E501
        """FinancialEvents - a model defined in Swagger"""  # noqa: E501
        self._shipment_event_list = None
        self._refund_event_list = None
        self._guarantee_claim_event_list = None
        self._chargeback_event_list = None
        self._pay_with_amazon_event_list = None
        self._service_provider_credit_event_list = None
        self._retrocharge_event_list = None
        self._rental_transaction_event_list = None
        self._product_ads_payment_event_list = None
        self._service_fee_event_list = None
        self._seller_deal_payment_event_list = None
        self._debt_recovery_event_list = None
        self._loan_servicing_event_list = None
        self._adjustment_event_list = None
        self._safet_reimbursement_event_list = None
        self._seller_review_enrollment_payment_event_list = None
        self._fba_liquidation_event_list = None
        self._coupon_payment_event_list = None
        self._imaging_services_fee_event_list = None
        self._network_commingling_transaction_event_list = None
        self._affordability_expense_event_list = None
        self._affordability_expense_reversal_event_list = None
        self.discriminator = None
        if shipment_event_list is not None:
            self.shipment_event_list = shipment_event_list
        if refund_event_list is not None:
            self.refund_event_list = refund_event_list
        if guarantee_claim_event_list is not None:
            self.guarantee_claim_event_list = guarantee_claim_event_list
        if chargeback_event_list is not None:
            self.chargeback_event_list = chargeback_event_list
        if pay_with_amazon_event_list is not None:
            self.pay_with_amazon_event_list = pay_with_amazon_event_list
        if service_provider_credit_event_list is not None:
            self.service_provider_credit_event_list = service_provider_credit_event_list
        if retrocharge_event_list is not None:
            self.retrocharge_event_list = retrocharge_event_list
        if rental_transaction_event_list is not None:
            self.rental_transaction_event_list = rental_transaction_event_list
        if product_ads_payment_event_list is not None:
            self.product_ads_payment_event_list = product_ads_payment_event_list
        if service_fee_event_list is not None:
            self.service_fee_event_list = service_fee_event_list
        if seller_deal_payment_event_list is not None:
            self.seller_deal_payment_event_list = seller_deal_payment_event_list
        if debt_recovery_event_list is not None:
            self.debt_recovery_event_list = debt_recovery_event_list
        if loan_servicing_event_list is not None:
            self.loan_servicing_event_list = loan_servicing_event_list
        if adjustment_event_list is not None:
            self.adjustment_event_list = adjustment_event_list
        if safet_reimbursement_event_list is not None:
            self.safet_reimbursement_event_list = safet_reimbursement_event_list
        if seller_review_enrollment_payment_event_list is not None:
            self.seller_review_enrollment_payment_event_list = seller_review_enrollment_payment_event_list
        if fba_liquidation_event_list is not None:
            self.fba_liquidation_event_list = fba_liquidation_event_list
        if coupon_payment_event_list is not None:
            self.coupon_payment_event_list = coupon_payment_event_list
        if imaging_services_fee_event_list is not None:
            self.imaging_services_fee_event_list = imaging_services_fee_event_list
        if network_commingling_transaction_event_list is not None:
            self.network_commingling_transaction_event_list = network_commingling_transaction_event_list
        if affordability_expense_event_list is not None:
            self.affordability_expense_event_list = affordability_expense_event_list
        if affordability_expense_reversal_event_list is not None:
            self.affordability_expense_reversal_event_list = affordability_expense_reversal_event_list

    @property
    def shipment_event_list(self):
        """Gets the shipment_event_list of this FinancialEvents.  # noqa: E501


        :return: The shipment_event_list of this FinancialEvents.  # noqa: E501
        :rtype: ShipmentEventList
        """
        return self._shipment_event_list

    @shipment_event_list.setter
    def shipment_event_list(self, shipment_event_list):
        """Sets the shipment_event_list of this FinancialEvents.


        :param shipment_event_list: The shipment_event_list of this FinancialEvents.  # noqa: E501
        :type: ShipmentEventList
        """

        self._shipment_event_list = shipment_event_list

    @property
    def refund_event_list(self):
        """Gets the refund_event_list of this FinancialEvents.  # noqa: E501


        :return: The refund_event_list of this FinancialEvents.  # noqa: E501
        :rtype: ShipmentEventList
        """
        return self._refund_event_list

    @refund_event_list.setter
    def refund_event_list(self, refund_event_list):
        """Sets the refund_event_list of this FinancialEvents.


        :param refund_event_list: The refund_event_list of this FinancialEvents.  # noqa: E501
        :type: ShipmentEventList
        """

        self._refund_event_list = refund_event_list

    @property
    def guarantee_claim_event_list(self):
        """Gets the guarantee_claim_event_list of this FinancialEvents.  # noqa: E501


        :return: The guarantee_claim_event_list of this FinancialEvents.  # noqa: E501
        :rtype: ShipmentEventList
        """
        return self._guarantee_claim_event_list

    @guarantee_claim_event_list.setter
    def guarantee_claim_event_list(self, guarantee_claim_event_list):
        """Sets the guarantee_claim_event_list of this FinancialEvents.


        :param guarantee_claim_event_list: The guarantee_claim_event_list of this FinancialEvents.  # noqa: E501
        :type: ShipmentEventList
        """

        self._guarantee_claim_event_list = guarantee_claim_event_list

    @property
    def chargeback_event_list(self):
        """Gets the chargeback_event_list of this FinancialEvents.  # noqa: E501


        :return: The chargeback_event_list of this FinancialEvents.  # noqa: E501
        :rtype: ShipmentEventList
        """
        return self._chargeback_event_list

    @chargeback_event_list.setter
    def chargeback_event_list(self, chargeback_event_list):
        """Sets the chargeback_event_list of this FinancialEvents.


        :param chargeback_event_list: The chargeback_event_list of this FinancialEvents.  # noqa: E501
        :type: ShipmentEventList
        """

        self._chargeback_event_list = chargeback_event_list

    @property
    def pay_with_amazon_event_list(self):
        """Gets the pay_with_amazon_event_list of this FinancialEvents.  # noqa: E501


        :return: The pay_with_amazon_event_list of this FinancialEvents.  # noqa: E501
        :rtype: PayWithAmazonEventList
        """
        return self._pay_with_amazon_event_list

    @pay_with_amazon_event_list.setter
    def pay_with_amazon_event_list(self, pay_with_amazon_event_list):
        """Sets the pay_with_amazon_event_list of this FinancialEvents.


        :param pay_with_amazon_event_list: The pay_with_amazon_event_list of this FinancialEvents.  # noqa: E501
        :type: PayWithAmazonEventList
        """

        self._pay_with_amazon_event_list = pay_with_amazon_event_list

    @property
    def service_provider_credit_event_list(self):
        """Gets the service_provider_credit_event_list of this FinancialEvents.  # noqa: E501


        :return: The service_provider_credit_event_list of this FinancialEvents.  # noqa: E501
        :rtype: SolutionProviderCreditEventList
        """
        return self._service_provider_credit_event_list

    @service_provider_credit_event_list.setter
    def service_provider_credit_event_list(self, service_provider_credit_event_list):
        """Sets the service_provider_credit_event_list of this FinancialEvents.


        :param service_provider_credit_event_list: The service_provider_credit_event_list of this FinancialEvents.  # noqa: E501
        :type: SolutionProviderCreditEventList
        """

        self._service_provider_credit_event_list = service_provider_credit_event_list

    @property
    def retrocharge_event_list(self):
        """Gets the retrocharge_event_list of this FinancialEvents.  # noqa: E501


        :return: The retrocharge_event_list of this FinancialEvents.  # noqa: E501
        :rtype: RetrochargeEventList
        """
        return self._retrocharge_event_list

    @retrocharge_event_list.setter
    def retrocharge_event_list(self, retrocharge_event_list):
        """Sets the retrocharge_event_list of this FinancialEvents.


        :param retrocharge_event_list: The retrocharge_event_list of this FinancialEvents.  # noqa: E501
        :type: RetrochargeEventList
        """

        self._retrocharge_event_list = retrocharge_event_list

    @property
    def rental_transaction_event_list(self):
        """Gets the rental_transaction_event_list of this FinancialEvents.  # noqa: E501


        :return: The rental_transaction_event_list of this FinancialEvents.  # noqa: E501
        :rtype: RentalTransactionEventList
        """
        return self._rental_transaction_event_list

    @rental_transaction_event_list.setter
    def rental_transaction_event_list(self, rental_transaction_event_list):
        """Sets the rental_transaction_event_list of this FinancialEvents.


        :param rental_transaction_event_list: The rental_transaction_event_list of this FinancialEvents.  # noqa: E501
        :type: RentalTransactionEventList
        """

        self._rental_transaction_event_list = rental_transaction_event_list

    @property
    def product_ads_payment_event_list(self):
        """Gets the product_ads_payment_event_list of this FinancialEvents.  # noqa: E501


        :return: The product_ads_payment_event_list of this FinancialEvents.  # noqa: E501
        :rtype: ProductAdsPaymentEventList
        """
        return self._product_ads_payment_event_list

    @product_ads_payment_event_list.setter
    def product_ads_payment_event_list(self, product_ads_payment_event_list):
        """Sets the product_ads_payment_event_list of this FinancialEvents.


        :param product_ads_payment_event_list: The product_ads_payment_event_list of this FinancialEvents.  # noqa: E501
        :type: ProductAdsPaymentEventList
        """

        self._product_ads_payment_event_list = product_ads_payment_event_list

    @property
    def service_fee_event_list(self):
        """Gets the service_fee_event_list of this FinancialEvents.  # noqa: E501


        :return: The service_fee_event_list of this FinancialEvents.  # noqa: E501
        :rtype: ServiceFeeEventList
        """
        return self._service_fee_event_list

    @service_fee_event_list.setter
    def service_fee_event_list(self, service_fee_event_list):
        """Sets the service_fee_event_list of this FinancialEvents.


        :param service_fee_event_list: The service_fee_event_list of this FinancialEvents.  # noqa: E501
        :type: ServiceFeeEventList
        """

        self._service_fee_event_list = service_fee_event_list

    @property
    def seller_deal_payment_event_list(self):
        """Gets the seller_deal_payment_event_list of this FinancialEvents.  # noqa: E501


        :return: The seller_deal_payment_event_list of this FinancialEvents.  # noqa: E501
        :rtype: SellerDealPaymentEventList
        """
        return self._seller_deal_payment_event_list

    @seller_deal_payment_event_list.setter
    def seller_deal_payment_event_list(self, seller_deal_payment_event_list):
        """Sets the seller_deal_payment_event_list of this FinancialEvents.


        :param seller_deal_payment_event_list: The seller_deal_payment_event_list of this FinancialEvents.  # noqa: E501
        :type: SellerDealPaymentEventList
        """

        self._seller_deal_payment_event_list = seller_deal_payment_event_list

    @property
    def debt_recovery_event_list(self):
        """Gets the debt_recovery_event_list of this FinancialEvents.  # noqa: E501


        :return: The debt_recovery_event_list of this FinancialEvents.  # noqa: E501
        :rtype: DebtRecoveryEventList
        """
        return self._debt_recovery_event_list

    @debt_recovery_event_list.setter
    def debt_recovery_event_list(self, debt_recovery_event_list):
        """Sets the debt_recovery_event_list of this FinancialEvents.


        :param debt_recovery_event_list: The debt_recovery_event_list of this FinancialEvents.  # noqa: E501
        :type: DebtRecoveryEventList
        """

        self._debt_recovery_event_list = debt_recovery_event_list

    @property
    def loan_servicing_event_list(self):
        """Gets the loan_servicing_event_list of this FinancialEvents.  # noqa: E501


        :return: The loan_servicing_event_list of this FinancialEvents.  # noqa: E501
        :rtype: LoanServicingEventList
        """
        return self._loan_servicing_event_list

    @loan_servicing_event_list.setter
    def loan_servicing_event_list(self, loan_servicing_event_list):
        """Sets the loan_servicing_event_list of this FinancialEvents.


        :param loan_servicing_event_list: The loan_servicing_event_list of this FinancialEvents.  # noqa: E501
        :type: LoanServicingEventList
        """

        self._loan_servicing_event_list = loan_servicing_event_list

    @property
    def adjustment_event_list(self):
        """Gets the adjustment_event_list of this FinancialEvents.  # noqa: E501


        :return: The adjustment_event_list of this FinancialEvents.  # noqa: E501
        :rtype: AdjustmentEventList
        """
        return self._adjustment_event_list

    @adjustment_event_list.setter
    def adjustment_event_list(self, adjustment_event_list):
        """Sets the adjustment_event_list of this FinancialEvents.


        :param adjustment_event_list: The adjustment_event_list of this FinancialEvents.  # noqa: E501
        :type: AdjustmentEventList
        """

        self._adjustment_event_list = adjustment_event_list

    @property
    def safet_reimbursement_event_list(self):
        """Gets the safet_reimbursement_event_list of this FinancialEvents.  # noqa: E501


        :return: The safet_reimbursement_event_list of this FinancialEvents.  # noqa: E501
        :rtype: SAFETReimbursementEventList
        """
        return self._safet_reimbursement_event_list

    @safet_reimbursement_event_list.setter
    def safet_reimbursement_event_list(self, safet_reimbursement_event_list):
        """Sets the safet_reimbursement_event_list of this FinancialEvents.


        :param safet_reimbursement_event_list: The safet_reimbursement_event_list of this FinancialEvents.  # noqa: E501
        :type: SAFETReimbursementEventList
        """

        self._safet_reimbursement_event_list = safet_reimbursement_event_list

    @property
    def seller_review_enrollment_payment_event_list(self):
        """Gets the seller_review_enrollment_payment_event_list of this FinancialEvents.  # noqa: E501


        :return: The seller_review_enrollment_payment_event_list of this FinancialEvents.  # noqa: E501
        :rtype: SellerReviewEnrollmentPaymentEventList
        """
        return self._seller_review_enrollment_payment_event_list

    @seller_review_enrollment_payment_event_list.setter
    def seller_review_enrollment_payment_event_list(self, seller_review_enrollment_payment_event_list):
        """Sets the seller_review_enrollment_payment_event_list of this FinancialEvents.


        :param seller_review_enrollment_payment_event_list: The seller_review_enrollment_payment_event_list of this FinancialEvents.  # noqa: E501
        :type: SellerReviewEnrollmentPaymentEventList
        """

        self._seller_review_enrollment_payment_event_list = seller_review_enrollment_payment_event_list

    @property
    def fba_liquidation_event_list(self):
        """Gets the fba_liquidation_event_list of this FinancialEvents.  # noqa: E501


        :return: The fba_liquidation_event_list of this FinancialEvents.  # noqa: E501
        :rtype: FBALiquidationEventList
        """
        return self._fba_liquidation_event_list

    @fba_liquidation_event_list.setter
    def fba_liquidation_event_list(self, fba_liquidation_event_list):
        """Sets the fba_liquidation_event_list of this FinancialEvents.


        :param fba_liquidation_event_list: The fba_liquidation_event_list of this FinancialEvents.  # noqa: E501
        :type: FBALiquidationEventList
        """

        self._fba_liquidation_event_list = fba_liquidation_event_list

    @property
    def coupon_payment_event_list(self):
        """Gets the coupon_payment_event_list of this FinancialEvents.  # noqa: E501


        :return: The coupon_payment_event_list of this FinancialEvents.  # noqa: E501
        :rtype: CouponPaymentEventList
        """
        return self._coupon_payment_event_list

    @coupon_payment_event_list.setter
    def coupon_payment_event_list(self, coupon_payment_event_list):
        """Sets the coupon_payment_event_list of this FinancialEvents.


        :param coupon_payment_event_list: The coupon_payment_event_list of this FinancialEvents.  # noqa: E501
        :type: CouponPaymentEventList
        """

        self._coupon_payment_event_list = coupon_payment_event_list

    @property
    def imaging_services_fee_event_list(self):
        """Gets the imaging_services_fee_event_list of this FinancialEvents.  # noqa: E501


        :return: The imaging_services_fee_event_list of this FinancialEvents.  # noqa: E501
        :rtype: ImagingServicesFeeEventList
        """
        return self._imaging_services_fee_event_list

    @imaging_services_fee_event_list.setter
    def imaging_services_fee_event_list(self, imaging_services_fee_event_list):
        """Sets the imaging_services_fee_event_list of this FinancialEvents.


        :param imaging_services_fee_event_list: The imaging_services_fee_event_list of this FinancialEvents.  # noqa: E501
        :type: ImagingServicesFeeEventList
        """

        self._imaging_services_fee_event_list = imaging_services_fee_event_list

    @property
    def network_commingling_transaction_event_list(self):
        """Gets the network_commingling_transaction_event_list of this FinancialEvents.  # noqa: E501


        :return: The network_commingling_transaction_event_list of this FinancialEvents.  # noqa: E501
        :rtype: NetworkComminglingTransactionEventList
        """
        return self._network_commingling_transaction_event_list

    @network_commingling_transaction_event_list.setter
    def network_commingling_transaction_event_list(self, network_commingling_transaction_event_list):
        """Sets the network_commingling_transaction_event_list of this FinancialEvents.


        :param network_commingling_transaction_event_list: The network_commingling_transaction_event_list of this FinancialEvents.  # noqa: E501
        :type: NetworkComminglingTransactionEventList
        """

        self._network_commingling_transaction_event_list = network_commingling_transaction_event_list

    @property
    def affordability_expense_event_list(self):
        """Gets the affordability_expense_event_list of this FinancialEvents.  # noqa: E501


        :return: The affordability_expense_event_list of this FinancialEvents.  # noqa: E501
        :rtype: AffordabilityExpenseEventList
        """
        return self._affordability_expense_event_list

    @affordability_expense_event_list.setter
    def affordability_expense_event_list(self, affordability_expense_event_list):
        """Sets the affordability_expense_event_list of this FinancialEvents.


        :param affordability_expense_event_list: The affordability_expense_event_list of this FinancialEvents.  # noqa: E501
        :type: AffordabilityExpenseEventList
        """

        self._affordability_expense_event_list = affordability_expense_event_list

    @property
    def affordability_expense_reversal_event_list(self):
        """Gets the affordability_expense_reversal_event_list of this FinancialEvents.  # noqa: E501


        :return: The affordability_expense_reversal_event_list of this FinancialEvents.  # noqa: E501
        :rtype: AffordabilityExpenseEventList
        """
        return self._affordability_expense_reversal_event_list

    @affordability_expense_reversal_event_list.setter
    def affordability_expense_reversal_event_list(self, affordability_expense_reversal_event_list):
        """Sets the affordability_expense_reversal_event_list of this FinancialEvents.


        :param affordability_expense_reversal_event_list: The affordability_expense_reversal_event_list of this FinancialEvents.  # noqa: E501
        :type: AffordabilityExpenseEventList
        """

        self._affordability_expense_reversal_event_list = affordability_expense_reversal_event_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FinancialEvents, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FinancialEvents):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Orders

    The Selling Partner API for Orders helps you programmatically retrieve order information. These APIs let you develop fast, flexible, custom applications in areas like order synchronization, order research, and demand-based decision support tools.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class OrderAddress(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amazon_order_id': 'str',
        'shipping_address': 'Address'
    }

    attribute_map = {
        'amazon_order_id': 'AmazonOrderId',
        'shipping_address': 'ShippingAddress'
    }

    def __init__(self, amazon_order_id=None, shipping_address=None):  # noqa: E501
        """OrderAddress - a model defined in Swagger"""  # noqa: E501
        self._amazon_order_id = None
        self._shipping_address = None
        self.discriminator = None
        self.amazon_order_id = amazon_order_id
        if shipping_address is not None:
            self.shipping_address = shipping_address

    @property
    def amazon_order_id(self):
        """Gets the amazon_order_id of this OrderAddress.  # noqa: E501

        An Amazon-defined order identifier, in 3-7-7 format.  # noqa: E501

        :return: The amazon_order_id of this OrderAddress.  # noqa: E501
        :rtype: str
        """
        return self._amazon_order_id

    @amazon_order_id.setter
    def amazon_order_id(self, amazon_order_id):
        """Sets the amazon_order_id of this OrderAddress.

        An Amazon-defined order identifier, in 3-7-7 format.  # noqa: E501

        :param amazon_order_id: The amazon_order_id of this OrderAddress.  # noqa: E501
        :type: str
        """
        if amazon_order_id is None:
            raise ValueError("Invalid value for `amazon_order_id`, must not be `None`")  # noqa: E501

        self._amazon_order_id = amazon_order_id

    @property
    def shipping_address(self):
        """Gets the shipping_address of this OrderAddress.  # noqa: E501


        :return: The shipping_address of this OrderAddress.  # noqa: E501
        :rtype: Address
        """
        return self._shipping_address

    @shipping_address.setter
    def shipping_address(self, shipping_address):
        """Sets the shipping_address of this OrderAddress.


        :param shipping_address: The shipping_address of this OrderAddress.  # noqa: E501
        :type: Address
        """

        self._shipping_address = shipping_address

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OrderAddress, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrderAddress):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from enum import Enum


class Granularity(Enum):
    HOUR = 'Hour'
    DAY = 'Day'
    WEEK = 'Week'
    MONTH = 'Month'
    YEAR = 'Year'
    TOTAL = 'Total'


class BuyerType(Enum):
    B2B = 'B2B' # Business to business.
    B2C = 'B2C' # Business to customer.
    ALL = 'All' # Both of above


class FirstDayOfWeek(Enum):
    MO = 'Monday'
    SU = 'Sunday'





# coding: utf-8

"""
    Selling Partner API for Sellers

    The Selling Partner API for Sellers lets you retrieve information on behalf of sellers about their seller account, such as the marketplaces they participate in. Along with listing the marketplaces that a seller can sell in, the API also provides additional information about the marketplace such as the default language and the default currency. The API also provides seller-specific information such as whether the seller has suspended listings in that marketplace.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from models.marketplace_participation_list import MarketplaceParticipationList  # noqa: E501
from swagger_client.rest import ApiException


class TestMarketplaceParticipationList(unittest.TestCase):
    """MarketplaceParticipationList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMarketplaceParticipationList(self):
        """Test MarketplaceParticipationList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.marketplace_participation_list.MarketplaceParticipationList()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Selling Partner API for Finances

    The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ProductAdsPaymentEvent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'posted_date': 'ModelDate',
        'transaction_type': 'str',
        'invoice_id': 'str',
        'base_value': 'Currency',
        'tax_value': 'Currency',
        'transaction_value': 'Currency'
    }

    attribute_map = {
        'posted_date': 'postedDate',
        'transaction_type': 'transactionType',
        'invoice_id': 'invoiceId',
        'base_value': 'baseValue',
        'tax_value': 'taxValue',
        'transaction_value': 'transactionValue'
    }

    def __init__(self, posted_date=None, transaction_type=None, invoice_id=None, base_value=None, tax_value=None, transaction_value=None):  # noqa: E501
        """ProductAdsPaymentEvent - a model defined in Swagger"""  # noqa: E501
        self._posted_date = None
        self._transaction_type = None
        self._invoice_id = None
        self._base_value = None
        self._tax_value = None
        self._transaction_value = None
        self.discriminator = None
        if posted_date is not None:
            self.posted_date = posted_date
        if transaction_type is not None:
            self.transaction_type = transaction_type
        if invoice_id is not None:
            self.invoice_id = invoice_id
        if base_value is not None:
            self.base_value = base_value
        if tax_value is not None:
            self.tax_value = tax_value
        if transaction_value is not None:
            self.transaction_value = transaction_value

    @property
    def posted_date(self):
        """Gets the posted_date of this ProductAdsPaymentEvent.  # noqa: E501


        :return: The posted_date of this ProductAdsPaymentEvent.  # noqa: E501
        :rtype: ModelDate
        """
        return self._posted_date

    @posted_date.setter
    def posted_date(self, posted_date):
        """Sets the posted_date of this ProductAdsPaymentEvent.


        :param posted_date: The posted_date of this ProductAdsPaymentEvent.  # noqa: E501
        :type: ModelDate
        """

        self._posted_date = posted_date

    @property
    def transaction_type(self):
        """Gets the transaction_type of this ProductAdsPaymentEvent.  # noqa: E501

        Indicates if the transaction is for a charge or a refund.  Possible values:  * charge - Charge  * refund - Refund  # noqa: E501

        :return: The transaction_type of this ProductAdsPaymentEvent.  # noqa: E501
        :rtype: str
        """
        return self._transaction_type

    @transaction_type.setter
    def transaction_type(self, transaction_type):
        """Sets the transaction_type of this ProductAdsPaymentEvent.

        Indicates if the transaction is for a charge or a refund.  Possible values:  * charge - Charge  * refund - Refund  # noqa: E501

        :param transaction_type: The transaction_type of this ProductAdsPaymentEvent.  # noqa: E501
        :type: str
        """

        self._transaction_type = transaction_type

    @property
    def invoice_id(self):
        """Gets the invoice_id of this ProductAdsPaymentEvent.  # noqa: E501

        Identifier for the invoice that the transaction appears in.  # noqa: E501

        :return: The invoice_id of this ProductAdsPaymentEvent.  # noqa: E501
        :rtype: str
        """
        return self._invoice_id

    @invoice_id.setter
    def invoice_id(self, invoice_id):
        """Sets the invoice_id of this ProductAdsPaymentEvent.

        Identifier for the invoice that the transaction appears in.  # noqa: E501

        :param invoice_id: The invoice_id of this ProductAdsPaymentEvent.  # noqa: E501
        :type: str
        """

        self._invoice_id = invoice_id

    @property
    def base_value(self):
        """Gets the base_value of this ProductAdsPaymentEvent.  # noqa: E501


        :return: The base_value of this ProductAdsPaymentEvent.  # noqa: E501
        :rtype: Currency
        """
        return self._base_value

    @base_value.setter
    def base_value(self, base_value):
        """Sets the base_value of this ProductAdsPaymentEvent.


        :param base_value: The base_value of this ProductAdsPaymentEvent.  # noqa: E501
        :type: Currency
        """

        self._base_value = base_value

    @property
    def tax_value(self):
        """Gets the tax_value of this ProductAdsPaymentEvent.  # noqa: E501


        :return: The tax_value of this ProductAdsPaymentEvent.  # noqa: E501
        :rtype: Currency
        """
        return self._tax_value

    @tax_value.setter
    def tax_value(self, tax_value):
        """Sets the tax_value of this ProductAdsPaymentEvent.


        :param tax_value: The tax_value of this ProductAdsPaymentEvent.  # noqa: E501
        :type: Currency
        """

        self._tax_value = tax_value

    @property
    def transaction_value(self):
        """Gets the transaction_value of this ProductAdsPaymentEvent.  # noqa: E501


        :return: The transaction_value of this ProductAdsPaymentEvent.  # noqa: E501
        :rtype: Currency
        """
        return self._transaction_value

    @transaction_value.setter
    def transaction_value(self, transaction_value):
        """Sets the transaction_value of this ProductAdsPaymentEvent.


        :param transaction_value: The transaction_value of this ProductAdsPaymentEvent.  # noqa: E501
        :type: Currency
        """

        self._transaction_value = transaction_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProductAdsPaymentEvent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProductAdsPaymentEvent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Finances

    The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class NetworkComminglingTransactionEvent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'transaction_type': 'str',
        'posted_date': 'ModelDate',
        'net_co_transaction_id': 'str',
        'swap_reason': 'str',
        'asin': 'str',
        'marketplace_id': 'str',
        'tax_exclusive_amount': 'Currency',
        'tax_amount': 'Currency'
    }

    attribute_map = {
        'transaction_type': 'TransactionType',
        'posted_date': 'PostedDate',
        'net_co_transaction_id': 'NetCoTransactionID',
        'swap_reason': 'SwapReason',
        'asin': 'ASIN',
        'marketplace_id': 'MarketplaceId',
        'tax_exclusive_amount': 'TaxExclusiveAmount',
        'tax_amount': 'TaxAmount'
    }

    def __init__(self, transaction_type=None, posted_date=None, net_co_transaction_id=None, swap_reason=None, asin=None, marketplace_id=None, tax_exclusive_amount=None, tax_amount=None):  # noqa: E501
        """NetworkComminglingTransactionEvent - a model defined in Swagger"""  # noqa: E501
        self._transaction_type = None
        self._posted_date = None
        self._net_co_transaction_id = None
        self._swap_reason = None
        self._asin = None
        self._marketplace_id = None
        self._tax_exclusive_amount = None
        self._tax_amount = None
        self.discriminator = None
        if transaction_type is not None:
            self.transaction_type = transaction_type
        if posted_date is not None:
            self.posted_date = posted_date
        if net_co_transaction_id is not None:
            self.net_co_transaction_id = net_co_transaction_id
        if swap_reason is not None:
            self.swap_reason = swap_reason
        if asin is not None:
            self.asin = asin
        if marketplace_id is not None:
            self.marketplace_id = marketplace_id
        if tax_exclusive_amount is not None:
            self.tax_exclusive_amount = tax_exclusive_amount
        if tax_amount is not None:
            self.tax_amount = tax_amount

    @property
    def transaction_type(self):
        """Gets the transaction_type of this NetworkComminglingTransactionEvent.  # noqa: E501

        The type of network item swap.  Possible values:  * NetCo - A Fulfillment by Amazon inventory pooling transaction. Available only in the India marketplace.  * ComminglingVAT - A commingling VAT transaction. Available only in the UK, Spain, France, Germany, and Italy marketplaces.  # noqa: E501

        :return: The transaction_type of this NetworkComminglingTransactionEvent.  # noqa: E501
        :rtype: str
        """
        return self._transaction_type

    @transaction_type.setter
    def transaction_type(self, transaction_type):
        """Sets the transaction_type of this NetworkComminglingTransactionEvent.

        The type of network item swap.  Possible values:  * NetCo - A Fulfillment by Amazon inventory pooling transaction. Available only in the India marketplace.  * ComminglingVAT - A commingling VAT transaction. Available only in the UK, Spain, France, Germany, and Italy marketplaces.  # noqa: E501

        :param transaction_type: The transaction_type of this NetworkComminglingTransactionEvent.  # noqa: E501
        :type: str
        """

        self._transaction_type = transaction_type

    @property
    def posted_date(self):
        """Gets the posted_date of this NetworkComminglingTransactionEvent.  # noqa: E501


        :return: The posted_date of this NetworkComminglingTransactionEvent.  # noqa: E501
        :rtype: ModelDate
        """
        return self._posted_date

    @posted_date.setter
    def posted_date(self, posted_date):
        """Sets the posted_date of this NetworkComminglingTransactionEvent.


        :param posted_date: The posted_date of this NetworkComminglingTransactionEvent.  # noqa: E501
        :type: ModelDate
        """

        self._posted_date = posted_date

    @property
    def net_co_transaction_id(self):
        """Gets the net_co_transaction_id of this NetworkComminglingTransactionEvent.  # noqa: E501

        The identifier for the network item swap.  # noqa: E501

        :return: The net_co_transaction_id of this NetworkComminglingTransactionEvent.  # noqa: E501
        :rtype: str
        """
        return self._net_co_transaction_id

    @net_co_transaction_id.setter
    def net_co_transaction_id(self, net_co_transaction_id):
        """Sets the net_co_transaction_id of this NetworkComminglingTransactionEvent.

        The identifier for the network item swap.  # noqa: E501

        :param net_co_transaction_id: The net_co_transaction_id of this NetworkComminglingTransactionEvent.  # noqa: E501
        :type: str
        """

        self._net_co_transaction_id = net_co_transaction_id

    @property
    def swap_reason(self):
        """Gets the swap_reason of this NetworkComminglingTransactionEvent.  # noqa: E501

        The reason for the network item swap.  # noqa: E501

        :return: The swap_reason of this NetworkComminglingTransactionEvent.  # noqa: E501
        :rtype: str
        """
        return self._swap_reason

    @swap_reason.setter
    def swap_reason(self, swap_reason):
        """Sets the swap_reason of this NetworkComminglingTransactionEvent.

        The reason for the network item swap.  # noqa: E501

        :param swap_reason: The swap_reason of this NetworkComminglingTransactionEvent.  # noqa: E501
        :type: str
        """

        self._swap_reason = swap_reason

    @property
    def asin(self):
        """Gets the asin of this NetworkComminglingTransactionEvent.  # noqa: E501

        The Amazon Standard Identification Number (ASIN) of the swapped item.  # noqa: E501

        :return: The asin of this NetworkComminglingTransactionEvent.  # noqa: E501
        :rtype: str
        """
        return self._asin

    @asin.setter
    def asin(self, asin):
        """Sets the asin of this NetworkComminglingTransactionEvent.

        The Amazon Standard Identification Number (ASIN) of the swapped item.  # noqa: E501

        :param asin: The asin of this NetworkComminglingTransactionEvent.  # noqa: E501
        :type: str
        """

        self._asin = asin

    @property
    def marketplace_id(self):
        """Gets the marketplace_id of this NetworkComminglingTransactionEvent.  # noqa: E501

        The marketplace in which the event took place.  # noqa: E501

        :return: The marketplace_id of this NetworkComminglingTransactionEvent.  # noqa: E501
        :rtype: str
        """
        return self._marketplace_id

    @marketplace_id.setter
    def marketplace_id(self, marketplace_id):
        """Sets the marketplace_id of this NetworkComminglingTransactionEvent.

        The marketplace in which the event took place.  # noqa: E501

        :param marketplace_id: The marketplace_id of this NetworkComminglingTransactionEvent.  # noqa: E501
        :type: str
        """

        self._marketplace_id = marketplace_id

    @property
    def tax_exclusive_amount(self):
        """Gets the tax_exclusive_amount of this NetworkComminglingTransactionEvent.  # noqa: E501


        :return: The tax_exclusive_amount of this NetworkComminglingTransactionEvent.  # noqa: E501
        :rtype: Currency
        """
        return self._tax_exclusive_amount

    @tax_exclusive_amount.setter
    def tax_exclusive_amount(self, tax_exclusive_amount):
        """Sets the tax_exclusive_amount of this NetworkComminglingTransactionEvent.


        :param tax_exclusive_amount: The tax_exclusive_amount of this NetworkComminglingTransactionEvent.  # noqa: E501
        :type: Currency
        """

        self._tax_exclusive_amount = tax_exclusive_amount

    @property
    def tax_amount(self):
        """Gets the tax_amount of this NetworkComminglingTransactionEvent.  # noqa: E501


        :return: The tax_amount of this NetworkComminglingTransactionEvent.  # noqa: E501
        :rtype: Currency
        """
        return self._tax_amount

    @tax_amount.setter
    def tax_amount(self, tax_amount):
        """Sets the tax_amount of this NetworkComminglingTransactionEvent.


        :param tax_amount: The tax_amount of this NetworkComminglingTransactionEvent.  # noqa: E501
        :type: Currency
        """

        self._tax_amount = tax_amount

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NetworkComminglingTransactionEvent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NetworkComminglingTransactionEvent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Orders

    The Selling Partner API for Orders helps you programmatically retrieve order information. These APIs let you develop fast, flexible, custom applications in areas like order synchronization, order research, and demand-based decision support tools.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class BuyerTaxInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'company_legal_name': 'str',
        'taxing_region': 'str',
        'tax_classifications': 'list[TaxClassification]'
    }

    attribute_map = {
        'company_legal_name': 'CompanyLegalName',
        'taxing_region': 'TaxingRegion',
        'tax_classifications': 'TaxClassifications'
    }

    def __init__(self, company_legal_name=None, taxing_region=None, tax_classifications=None):  # noqa: E501
        """BuyerTaxInfo - a model defined in Swagger"""  # noqa: E501
        self._company_legal_name = None
        self._taxing_region = None
        self._tax_classifications = None
        self.discriminator = None
        if company_legal_name is not None:
            self.company_legal_name = company_legal_name
        if taxing_region is not None:
            self.taxing_region = taxing_region
        if tax_classifications is not None:
            self.tax_classifications = tax_classifications

    @property
    def company_legal_name(self):
        """Gets the company_legal_name of this BuyerTaxInfo.  # noqa: E501

        The legal name of the company.  # noqa: E501

        :return: The company_legal_name of this BuyerTaxInfo.  # noqa: E501
        :rtype: str
        """
        return self._company_legal_name

    @company_legal_name.setter
    def company_legal_name(self, company_legal_name):
        """Sets the company_legal_name of this BuyerTaxInfo.

        The legal name of the company.  # noqa: E501

        :param company_legal_name: The company_legal_name of this BuyerTaxInfo.  # noqa: E501
        :type: str
        """

        self._company_legal_name = company_legal_name

    @property
    def taxing_region(self):
        """Gets the taxing_region of this BuyerTaxInfo.  # noqa: E501

        The country or region imposing the tax.  # noqa: E501

        :return: The taxing_region of this BuyerTaxInfo.  # noqa: E501
        :rtype: str
        """
        return self._taxing_region

    @taxing_region.setter
    def taxing_region(self, taxing_region):
        """Sets the taxing_region of this BuyerTaxInfo.

        The country or region imposing the tax.  # noqa: E501

        :param taxing_region: The taxing_region of this BuyerTaxInfo.  # noqa: E501
        :type: str
        """

        self._taxing_region = taxing_region

    @property
    def tax_classifications(self):
        """Gets the tax_classifications of this BuyerTaxInfo.  # noqa: E501

        A list of tax classifications that apply to the order.  # noqa: E501

        :return: The tax_classifications of this BuyerTaxInfo.  # noqa: E501
        :rtype: list[TaxClassification]
        """
        return self._tax_classifications

    @tax_classifications.setter
    def tax_classifications(self, tax_classifications):
        """Sets the tax_classifications of this BuyerTaxInfo.

        A list of tax classifications that apply to the order.  # noqa: E501

        :param tax_classifications: The tax_classifications of this BuyerTaxInfo.  # noqa: E501
        :type: list[TaxClassification]
        """

        self._tax_classifications = tax_classifications

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BuyerTaxInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BuyerTaxInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from sp_api.base.helpers import sp_endpoint, fill_query_params
from sp_api.api.notifications.models.create_destination_response import CreateDestinationResponse
from sp_api.api.notifications.models.create_subscription_response import CreateSubscriptionResponse
from sp_api.api.notifications.models.delete_destination_response import DeleteDestinationResponse
from sp_api.api.notifications.models.delete_subscription_by_id_response import DeleteSubscriptionByIdResponse
from sp_api.api.notifications.models.get_destination_response import GetDestinationResponse
from sp_api.api.notifications.models.get_destinations_response import GetDestinationsResponse
from sp_api.api.notifications.models.get_subscription_by_id_response import GetSubscriptionByIdResponse
from sp_api.api.notifications.models.get_subscription_response import GetSubscriptionResponse
from sp_api.base import Client, Marketplaces, deprecated, NotificationType


class Notifications(Client):
    """
    Endpoints:
        /notifications/v1/subscriptions/{notificationType}
        /notifications/v1/subscriptions/{notificationType}/{subscriptionId}
        /notifications/v1/destinations
        /notifications/v1/destinations/{destinationId}
    """

    def __init__(self, marketplace=Marketplaces.US, *, refresh_token=None):
        super().__init__(marketplace, refresh_token)

    @deprecated
    def add_subscription(self, notification_type: NotificationType or str, **kwargs):
        return self.create_subscription(notification_type, **kwargs)

    @sp_endpoint('/notifications/v1/subscriptions/{}', method='POST')
    def create_subscription(self, notification_type: NotificationType or str, destination_id: str = None, **kwargs):
        """
        Creates a subscription for the specified notification type to be delivered to the specified destination.
        Before you can subscribe, you must first create the destination by calling the createDestination operation.

        **Usage Plan:**

        | Rate (requests per second) | Burst |
        | ---- | ---- |
        | 1 | 5 |

        For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.

        :param destination_id: str
        :param notification_type: str
        :param kwargs:
        :return:
        """
        data = {
            'destinationId': kwargs.pop('destinationId', destination_id),
            'payloadVersion': kwargs.pop('payload_version', '1.0')
        }
        return CreateSubscriptionResponse(
            **self._request(fill_query_params(kwargs.pop('path'),
                                                                  notification_type if isinstance(notification_type,
                                                                                                  str) else notification_type.value),
                                                data={**kwargs, **data}).json()
        )

    @sp_endpoint('/notifications/v1/subscriptions/{}')
    def get_subscription(self, notification_type, **kwargs):
        """
        Returns information about subscriptions of the specified notification type. You can use this API to get subscription information when you do not have a subscription identifier.

        **Usage Plan:**

        | Rate (requests per second) | Burst |
        | ---- | ---- |
        | 1 | 5 |

        For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
        :param notification_type:
        :param kwargs:
        :return:
        """
        return GetSubscriptionResponse(
            **self._request(fill_query_params(kwargs.pop('path'), notification_type if isinstance(notification_type, str) else notification_type.value),
                                                params={**kwargs}).json()
        )

    @sp_endpoint('/notifications/v1/subscriptions/{}/{}', method='DELETE')
    def delete_notification_subscription(self, notification_type, subscription_id, **kwargs):
        """
        Deletes the subscription indicated by the subscription identifier and notification type that you specify.
        The subscription identifier can be for any subscription associated with your application. After you successfully call this operation, notifications will stop being sent for the associated subscription. The deleteSubscriptionById API is grantless. For more information, see "Grantless operations" in the Selling Partner API Developer Guide.

        **Usage Plan:**

        | Rate (requests per second) | Burst |
        | ---- | ---- |
        | 1 | 5 |

        For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
        :param notification_type:
        :param subscription_id:
        :param kwargs:
        :return:
        """
        return DeleteSubscriptionByIdResponse(
            **self._request(
                fill_query_params(kwargs.pop('path'), notification_type if isinstance(notification_type, str) else notification_type.value, subscription_id),
                params={**kwargs}).json()
        )

    @sp_endpoint(path='/notifications/v1/destinations', method='POST')
    def create_destination(self, name, arn, **kwargs):
        """
        Creates a destination resource to receive notifications. The createDestination API is grantless. For more information, see "Grantless operations" in the Selling Partner API Developer Guide.

        **Usage Plan:**

        | Rate (requests per second) | Burst |
        | ---- | ---- |
        | 1 | 5 |

        For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
        :param name:
        :param arn:
        :param kwargs:
        :return:
        """

        data = {
            'resourceSpecification': {
                'sqs': {
                    'arn': arn
                }
            },
            'name': name,
        }

        return CreateDestinationResponse(
            **self._request_grantless_operation(kwargs.pop('path'), data={**kwargs, **data}).json()
        )

    @sp_endpoint('/notifications/v1/destinations', method='GET')
    def get_destinations(self, **kwargs):
        """
        Returns information about all destinations. The getDestinations API is grantless. For more information, see "Grantless operations" in the Selling Partner API Developer Guide.

        **Usage Plan:**

        | Rate (requests per second) | Burst |
        | ---- | ---- |
        | 1 | 5 |

        For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
        :param kwargs:
        :return:
        """
        return GetDestinationsResponse(
            **self._request_grantless_operation(kwargs.pop('path'), params={**kwargs}).json()
        )

    @sp_endpoint('/notifications/v1/destinations/{}', method='GET')
    def get_destination(self, destination_id, **kwargs):
        """
        Returns information about all destinations. The getDestinations API is grantless. For more information, see "Grantless operations" in the Selling Partner API Developer Guide.

        **Usage Plan:**

        | Rate (requests per second) | Burst |
        | ---- | ---- |
        | 1 | 5 |

        For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
        :param destination_id:
        :param kwargs:
        :return:
        """
        return GetDestinationResponse(
            **self._request_grantless_operation(fill_query_params(kwargs.pop('path'), destination_id),
                                                params={**kwargs}).json()
        )

    @sp_endpoint('/notifications/v1/destinations/{}', method='DELETE')
    def delete_destination(self, destination_id, **kwargs):
        """
        Deletes the destination that you specify. The deleteDestination API is grantless. For more information, see "Grantless operations" in the Selling Partner API Developer Guide.

        **Usage Plan:**

        | Rate (requests per second) | Burst |
        | ---- | ---- |
        | 1 | 5 |

        For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.
        :param destination_id:
        :param kwargs:
        :return:
        """
        return DeleteDestinationResponse(
            **self._request_grantless_operation(fill_query_params(kwargs.pop('path'), destination_id),
                                                params={**kwargs}).json()
        )



# coding: utf-8

"""
    Selling Partner API for Finances

    The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class SellerReviewEnrollmentPaymentEvent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'posted_date': 'ModelDate',
        'enrollment_id': 'str',
        'parent_asin': 'str',
        'fee_component': 'FeeComponent',
        'charge_component': 'ChargeComponent',
        'total_amount': 'Currency'
    }

    attribute_map = {
        'posted_date': 'PostedDate',
        'enrollment_id': 'EnrollmentId',
        'parent_asin': 'ParentASIN',
        'fee_component': 'FeeComponent',
        'charge_component': 'ChargeComponent',
        'total_amount': 'TotalAmount'
    }

    def __init__(self, posted_date=None, enrollment_id=None, parent_asin=None, fee_component=None, charge_component=None, total_amount=None):  # noqa: E501
        """SellerReviewEnrollmentPaymentEvent - a model defined in Swagger"""  # noqa: E501
        self._posted_date = None
        self._enrollment_id = None
        self._parent_asin = None
        self._fee_component = None
        self._charge_component = None
        self._total_amount = None
        self.discriminator = None
        if posted_date is not None:
            self.posted_date = posted_date
        if enrollment_id is not None:
            self.enrollment_id = enrollment_id
        if parent_asin is not None:
            self.parent_asin = parent_asin
        if fee_component is not None:
            self.fee_component = fee_component
        if charge_component is not None:
            self.charge_component = charge_component
        if total_amount is not None:
            self.total_amount = total_amount

    @property
    def posted_date(self):
        """Gets the posted_date of this SellerReviewEnrollmentPaymentEvent.  # noqa: E501


        :return: The posted_date of this SellerReviewEnrollmentPaymentEvent.  # noqa: E501
        :rtype: ModelDate
        """
        return self._posted_date

    @posted_date.setter
    def posted_date(self, posted_date):
        """Sets the posted_date of this SellerReviewEnrollmentPaymentEvent.


        :param posted_date: The posted_date of this SellerReviewEnrollmentPaymentEvent.  # noqa: E501
        :type: ModelDate
        """

        self._posted_date = posted_date

    @property
    def enrollment_id(self):
        """Gets the enrollment_id of this SellerReviewEnrollmentPaymentEvent.  # noqa: E501

        An enrollment identifier.  # noqa: E501

        :return: The enrollment_id of this SellerReviewEnrollmentPaymentEvent.  # noqa: E501
        :rtype: str
        """
        return self._enrollment_id

    @enrollment_id.setter
    def enrollment_id(self, enrollment_id):
        """Sets the enrollment_id of this SellerReviewEnrollmentPaymentEvent.

        An enrollment identifier.  # noqa: E501

        :param enrollment_id: The enrollment_id of this SellerReviewEnrollmentPaymentEvent.  # noqa: E501
        :type: str
        """

        self._enrollment_id = enrollment_id

    @property
    def parent_asin(self):
        """Gets the parent_asin of this SellerReviewEnrollmentPaymentEvent.  # noqa: E501

        The Amazon Standard Identification Number (ASIN) of the item that was enrolled in the Early Reviewer Program.  # noqa: E501

        :return: The parent_asin of this SellerReviewEnrollmentPaymentEvent.  # noqa: E501
        :rtype: str
        """
        return self._parent_asin

    @parent_asin.setter
    def parent_asin(self, parent_asin):
        """Sets the parent_asin of this SellerReviewEnrollmentPaymentEvent.

        The Amazon Standard Identification Number (ASIN) of the item that was enrolled in the Early Reviewer Program.  # noqa: E501

        :param parent_asin: The parent_asin of this SellerReviewEnrollmentPaymentEvent.  # noqa: E501
        :type: str
        """

        self._parent_asin = parent_asin

    @property
    def fee_component(self):
        """Gets the fee_component of this SellerReviewEnrollmentPaymentEvent.  # noqa: E501


        :return: The fee_component of this SellerReviewEnrollmentPaymentEvent.  # noqa: E501
        :rtype: FeeComponent
        """
        return self._fee_component

    @fee_component.setter
    def fee_component(self, fee_component):
        """Sets the fee_component of this SellerReviewEnrollmentPaymentEvent.


        :param fee_component: The fee_component of this SellerReviewEnrollmentPaymentEvent.  # noqa: E501
        :type: FeeComponent
        """

        self._fee_component = fee_component

    @property
    def charge_component(self):
        """Gets the charge_component of this SellerReviewEnrollmentPaymentEvent.  # noqa: E501


        :return: The charge_component of this SellerReviewEnrollmentPaymentEvent.  # noqa: E501
        :rtype: ChargeComponent
        """
        return self._charge_component

    @charge_component.setter
    def charge_component(self, charge_component):
        """Sets the charge_component of this SellerReviewEnrollmentPaymentEvent.


        :param charge_component: The charge_component of this SellerReviewEnrollmentPaymentEvent.  # noqa: E501
        :type: ChargeComponent
        """

        self._charge_component = charge_component

    @property
    def total_amount(self):
        """Gets the total_amount of this SellerReviewEnrollmentPaymentEvent.  # noqa: E501


        :return: The total_amount of this SellerReviewEnrollmentPaymentEvent.  # noqa: E501
        :rtype: Currency
        """
        return self._total_amount

    @total_amount.setter
    def total_amount(self, total_amount):
        """Sets the total_amount of this SellerReviewEnrollmentPaymentEvent.


        :param total_amount: The total_amount of this SellerReviewEnrollmentPaymentEvent.  # noqa: E501
        :type: Currency
        """

        self._total_amount = total_amount

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SellerReviewEnrollmentPaymentEvent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SellerReviewEnrollmentPaymentEvent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Reports

    The Selling Partner API for Reports lets you retrieve and manage a variety of reports that can help selling partners manage their businesses.  # noqa: E501

    OpenAPI spec version: 2020-09-04
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ReportSchedule(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'report_schedule_id': 'str',
        'report_type': 'str',
        'marketplace_ids': 'list[str]',
        'report_options': 'ReportOptions',
        'period': 'str',
        'next_report_creation_time': 'datetime'
    }

    attribute_map = {
        'report_schedule_id': 'reportScheduleId',
        'report_type': 'reportType',
        'marketplace_ids': 'marketplaceIds',
        'report_options': 'reportOptions',
        'period': 'period',
        'next_report_creation_time': 'nextReportCreationTime'
    }

    def __init__(self, report_schedule_id=None, report_type=None, marketplace_ids=None, report_options=None, period=None, next_report_creation_time=None):  # noqa: E501
        """ReportSchedule - a model defined in Swagger"""  # noqa: E501
        self._report_schedule_id = None
        self._report_type = None
        self._marketplace_ids = None
        self._report_options = None
        self._period = None
        self._next_report_creation_time = None
        self.discriminator = None
        self.report_schedule_id = report_schedule_id
        self.report_type = report_type
        if marketplace_ids is not None:
            self.marketplace_ids = marketplace_ids
        if report_options is not None:
            self.report_options = report_options
        self.period = period
        if next_report_creation_time is not None:
            self.next_report_creation_time = next_report_creation_time

    @property
    def report_schedule_id(self):
        """Gets the report_schedule_id of this ReportSchedule.  # noqa: E501

        The identifier for the report schedule. This identifier is unique only in combination with a seller ID.  # noqa: E501

        :return: The report_schedule_id of this ReportSchedule.  # noqa: E501
        :rtype: str
        """
        return self._report_schedule_id

    @report_schedule_id.setter
    def report_schedule_id(self, report_schedule_id):
        """Sets the report_schedule_id of this ReportSchedule.

        The identifier for the report schedule. This identifier is unique only in combination with a seller ID.  # noqa: E501

        :param report_schedule_id: The report_schedule_id of this ReportSchedule.  # noqa: E501
        :type: str
        """
        if report_schedule_id is None:
            raise ValueError("Invalid value for `report_schedule_id`, must not be `None`")  # noqa: E501

        self._report_schedule_id = report_schedule_id

    @property
    def report_type(self):
        """Gets the report_type of this ReportSchedule.  # noqa: E501

        The report type.  # noqa: E501

        :return: The report_type of this ReportSchedule.  # noqa: E501
        :rtype: str
        """
        return self._report_type

    @report_type.setter
    def report_type(self, report_type):
        """Sets the report_type of this ReportSchedule.

        The report type.  # noqa: E501

        :param report_type: The report_type of this ReportSchedule.  # noqa: E501
        :type: str
        """
        if report_type is None:
            raise ValueError("Invalid value for `report_type`, must not be `None`")  # noqa: E501

        self._report_type = report_type

    @property
    def marketplace_ids(self):
        """Gets the marketplace_ids of this ReportSchedule.  # noqa: E501

        A list of marketplace identifiers. The report document's contents will contain data for all of the specified marketplaces, unless the report type indicates otherwise.  # noqa: E501

        :return: The marketplace_ids of this ReportSchedule.  # noqa: E501
        :rtype: list[str]
        """
        return self._marketplace_ids

    @marketplace_ids.setter
    def marketplace_ids(self, marketplace_ids):
        """Sets the marketplace_ids of this ReportSchedule.

        A list of marketplace identifiers. The report document's contents will contain data for all of the specified marketplaces, unless the report type indicates otherwise.  # noqa: E501

        :param marketplace_ids: The marketplace_ids of this ReportSchedule.  # noqa: E501
        :type: list[str]
        """

        self._marketplace_ids = marketplace_ids

    @property
    def report_options(self):
        """Gets the report_options of this ReportSchedule.  # noqa: E501


        :return: The report_options of this ReportSchedule.  # noqa: E501
        :rtype: ReportOptions
        """
        return self._report_options

    @report_options.setter
    def report_options(self, report_options):
        """Sets the report_options of this ReportSchedule.


        :param report_options: The report_options of this ReportSchedule.  # noqa: E501
        :type: ReportOptions
        """

        self._report_options = report_options

    @property
    def period(self):
        """Gets the period of this ReportSchedule.  # noqa: E501

        An ISO 8601 period value that indicates how often a report should be created.  # noqa: E501

        :return: The period of this ReportSchedule.  # noqa: E501
        :rtype: str
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this ReportSchedule.

        An ISO 8601 period value that indicates how often a report should be created.  # noqa: E501

        :param period: The period of this ReportSchedule.  # noqa: E501
        :type: str
        """
        if period is None:
            raise ValueError("Invalid value for `period`, must not be `None`")  # noqa: E501

        self._period = period

    @property
    def next_report_creation_time(self):
        """Gets the next_report_creation_time of this ReportSchedule.  # noqa: E501

        The date and time when the schedule will create its next report, in ISO 8601 date time format.  # noqa: E501

        :return: The next_report_creation_time of this ReportSchedule.  # noqa: E501
        :rtype: datetime
        """
        return self._next_report_creation_time

    @next_report_creation_time.setter
    def next_report_creation_time(self, next_report_creation_time):
        """Sets the next_report_creation_time of this ReportSchedule.

        The date and time when the schedule will create its next report, in ISO 8601 date time format.  # noqa: E501

        :param next_report_creation_time: The next_report_creation_time of this ReportSchedule.  # noqa: E501
        :type: datetime
        """

        self._next_report_creation_time = next_report_creation_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ReportSchedule, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReportSchedule):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Reports

    The Selling Partner API for Reports lets you retrieve and manage a variety of reports that can help selling partners manage their businesses.  # noqa: E501

    OpenAPI spec version: 2020-09-04
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ReportDocumentEncryptionDetails(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'standard': 'str',
        'initialization_vector': 'str',
        'key': 'str'
    }

    attribute_map = {
        'standard': 'standard',
        'initialization_vector': 'initializationVector',
        'key': 'key'
    }

    def __init__(self, standard=None, initialization_vector=None, key=None):  # noqa: E501
        """ReportDocumentEncryptionDetails - a model defined in Swagger"""  # noqa: E501
        self._standard = None
        self._initialization_vector = None
        self._key = None
        self.discriminator = None
        self.standard = standard
        self.initialization_vector = initialization_vector
        self.key = key

    @property
    def standard(self):
        """Gets the standard of this ReportDocumentEncryptionDetails.  # noqa: E501

        The encryption standard required to decrypt the document contents.  # noqa: E501

        :return: The standard of this ReportDocumentEncryptionDetails.  # noqa: E501
        :rtype: str
        """
        return self._standard

    @standard.setter
    def standard(self, standard):
        """Sets the standard of this ReportDocumentEncryptionDetails.

        The encryption standard required to decrypt the document contents.  # noqa: E501

        :param standard: The standard of this ReportDocumentEncryptionDetails.  # noqa: E501
        :type: str
        """
        if standard is None:
            raise ValueError("Invalid value for `standard`, must not be `None`")  # noqa: E501
        allowed_values = ["AES"]  # noqa: E501
        if standard not in allowed_values:
            raise ValueError(
                "Invalid value for `standard` ({0}), must be one of {1}"  # noqa: E501
                .format(standard, allowed_values)
            )

        self._standard = standard

    @property
    def initialization_vector(self):
        """Gets the initialization_vector of this ReportDocumentEncryptionDetails.  # noqa: E501

        The vector to decrypt the document contents using Cipher Block Chaining (CBC).  # noqa: E501

        :return: The initialization_vector of this ReportDocumentEncryptionDetails.  # noqa: E501
        :rtype: str
        """
        return self._initialization_vector

    @initialization_vector.setter
    def initialization_vector(self, initialization_vector):
        """Sets the initialization_vector of this ReportDocumentEncryptionDetails.

        The vector to decrypt the document contents using Cipher Block Chaining (CBC).  # noqa: E501

        :param initialization_vector: The initialization_vector of this ReportDocumentEncryptionDetails.  # noqa: E501
        :type: str
        """
        if initialization_vector is None:
            raise ValueError("Invalid value for `initialization_vector`, must not be `None`")  # noqa: E501

        self._initialization_vector = initialization_vector

    @property
    def key(self):
        """Gets the key of this ReportDocumentEncryptionDetails.  # noqa: E501

        The encryption key used to decrypt the document contents.  # noqa: E501

        :return: The key of this ReportDocumentEncryptionDetails.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this ReportDocumentEncryptionDetails.

        The encryption key used to decrypt the document contents.  # noqa: E501

        :param key: The key of this ReportDocumentEncryptionDetails.  # noqa: E501
        :type: str
        """
        if key is None:
            raise ValueError("Invalid value for `key`, must not be `None`")  # noqa: E501

        self._key = key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ReportDocumentEncryptionDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReportDocumentEncryptionDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Finances

    The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AdjustmentItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'quantity': 'str',
        'per_unit_amount': 'Currency',
        'total_amount': 'Currency',
        'seller_sku': 'str',
        'fn_sku': 'str',
        'product_description': 'str',
        'asin': 'str'
    }

    attribute_map = {
        'quantity': 'Quantity',
        'per_unit_amount': 'PerUnitAmount',
        'total_amount': 'TotalAmount',
        'seller_sku': 'SellerSKU',
        'fn_sku': 'FnSKU',
        'product_description': 'ProductDescription',
        'asin': 'ASIN'
    }

    def __init__(self, quantity=None, per_unit_amount=None, total_amount=None, seller_sku=None, fn_sku=None, product_description=None, asin=None):  # noqa: E501
        """AdjustmentItem - a model defined in Swagger"""  # noqa: E501
        self._quantity = None
        self._per_unit_amount = None
        self._total_amount = None
        self._seller_sku = None
        self._fn_sku = None
        self._product_description = None
        self._asin = None
        self.discriminator = None
        if quantity is not None:
            self.quantity = quantity
        if per_unit_amount is not None:
            self.per_unit_amount = per_unit_amount
        if total_amount is not None:
            self.total_amount = total_amount
        if seller_sku is not None:
            self.seller_sku = seller_sku
        if fn_sku is not None:
            self.fn_sku = fn_sku
        if product_description is not None:
            self.product_description = product_description
        if asin is not None:
            self.asin = asin

    @property
    def quantity(self):
        """Gets the quantity of this AdjustmentItem.  # noqa: E501

        Represents the number of units in the seller's inventory when the AdustmentType is FBAInventoryReimbursement.  # noqa: E501

        :return: The quantity of this AdjustmentItem.  # noqa: E501
        :rtype: str
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this AdjustmentItem.

        Represents the number of units in the seller's inventory when the AdustmentType is FBAInventoryReimbursement.  # noqa: E501

        :param quantity: The quantity of this AdjustmentItem.  # noqa: E501
        :type: str
        """

        self._quantity = quantity

    @property
    def per_unit_amount(self):
        """Gets the per_unit_amount of this AdjustmentItem.  # noqa: E501


        :return: The per_unit_amount of this AdjustmentItem.  # noqa: E501
        :rtype: Currency
        """
        return self._per_unit_amount

    @per_unit_amount.setter
    def per_unit_amount(self, per_unit_amount):
        """Sets the per_unit_amount of this AdjustmentItem.


        :param per_unit_amount: The per_unit_amount of this AdjustmentItem.  # noqa: E501
        :type: Currency
        """

        self._per_unit_amount = per_unit_amount

    @property
    def total_amount(self):
        """Gets the total_amount of this AdjustmentItem.  # noqa: E501


        :return: The total_amount of this AdjustmentItem.  # noqa: E501
        :rtype: Currency
        """
        return self._total_amount

    @total_amount.setter
    def total_amount(self, total_amount):
        """Sets the total_amount of this AdjustmentItem.


        :param total_amount: The total_amount of this AdjustmentItem.  # noqa: E501
        :type: Currency
        """

        self._total_amount = total_amount

    @property
    def seller_sku(self):
        """Gets the seller_sku of this AdjustmentItem.  # noqa: E501

        The seller SKU of the item. The seller SKU is qualified by the seller's seller ID, which is included with every call to the Selling Partner API.  # noqa: E501

        :return: The seller_sku of this AdjustmentItem.  # noqa: E501
        :rtype: str
        """
        return self._seller_sku

    @seller_sku.setter
    def seller_sku(self, seller_sku):
        """Sets the seller_sku of this AdjustmentItem.

        The seller SKU of the item. The seller SKU is qualified by the seller's seller ID, which is included with every call to the Selling Partner API.  # noqa: E501

        :param seller_sku: The seller_sku of this AdjustmentItem.  # noqa: E501
        :type: str
        """

        self._seller_sku = seller_sku

    @property
    def fn_sku(self):
        """Gets the fn_sku of this AdjustmentItem.  # noqa: E501

        A unique identifier assigned to products stored in and fulfilled from a fulfillment center.  # noqa: E501

        :return: The fn_sku of this AdjustmentItem.  # noqa: E501
        :rtype: str
        """
        return self._fn_sku

    @fn_sku.setter
    def fn_sku(self, fn_sku):
        """Sets the fn_sku of this AdjustmentItem.

        A unique identifier assigned to products stored in and fulfilled from a fulfillment center.  # noqa: E501

        :param fn_sku: The fn_sku of this AdjustmentItem.  # noqa: E501
        :type: str
        """

        self._fn_sku = fn_sku

    @property
    def product_description(self):
        """Gets the product_description of this AdjustmentItem.  # noqa: E501

        A short description of the item.  # noqa: E501

        :return: The product_description of this AdjustmentItem.  # noqa: E501
        :rtype: str
        """
        return self._product_description

    @product_description.setter
    def product_description(self, product_description):
        """Sets the product_description of this AdjustmentItem.

        A short description of the item.  # noqa: E501

        :param product_description: The product_description of this AdjustmentItem.  # noqa: E501
        :type: str
        """

        self._product_description = product_description

    @property
    def asin(self):
        """Gets the asin of this AdjustmentItem.  # noqa: E501

        The Amazon Standard Identification Number (ASIN) of the item.  # noqa: E501

        :return: The asin of this AdjustmentItem.  # noqa: E501
        :rtype: str
        """
        return self._asin

    @asin.setter
    def asin(self, asin):
        """Sets the asin of this AdjustmentItem.

        The Amazon Standard Identification Number (ASIN) of the item.  # noqa: E501

        :param asin: The asin of this AdjustmentItem.  # noqa: E501
        :type: str
        """

        self._asin = asin

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AdjustmentItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdjustmentItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Pricing

    The Selling Partner API for Pricing helps you programmatically retrieve product pricing and offer information for Amazon Marketplace products.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class CompetitivePriceType(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'competitive_price_id': 'str',
        'price': 'PriceType',
        'condition': 'str',
        'subcondition': 'str',
        'belongs_to_requester': 'bool'
    }

    attribute_map = {
        'competitive_price_id': 'CompetitivePriceId',
        'price': 'Price',
        'condition': 'condition',
        'subcondition': 'subcondition',
        'belongs_to_requester': 'belongsToRequester'
    }

    def __init__(self, competitive_price_id=None, price=None, condition=None, subcondition=None, belongs_to_requester=None):  # noqa: E501
        """CompetitivePriceType - a model defined in Swagger"""  # noqa: E501
        self._competitive_price_id = None
        self._price = None
        self._condition = None
        self._subcondition = None
        self._belongs_to_requester = None
        self.discriminator = None
        self.competitive_price_id = competitive_price_id
        self.price = price
        if condition is not None:
            self.condition = condition
        if subcondition is not None:
            self.subcondition = subcondition
        if belongs_to_requester is not None:
            self.belongs_to_requester = belongs_to_requester

    @property
    def competitive_price_id(self):
        """Gets the competitive_price_id of this CompetitivePriceType.  # noqa: E501

        The pricing model for each price that is returned.  Possible values:  * 1 - New Buy Box Price. * 2 - Used Buy Box Price.  # noqa: E501

        :return: The competitive_price_id of this CompetitivePriceType.  # noqa: E501
        :rtype: str
        """
        return self._competitive_price_id

    @competitive_price_id.setter
    def competitive_price_id(self, competitive_price_id):
        """Sets the competitive_price_id of this CompetitivePriceType.

        The pricing model for each price that is returned.  Possible values:  * 1 - New Buy Box Price. * 2 - Used Buy Box Price.  # noqa: E501

        :param competitive_price_id: The competitive_price_id of this CompetitivePriceType.  # noqa: E501
        :type: str
        """
        if competitive_price_id is None:
            raise ValueError("Invalid value for `competitive_price_id`, must not be `None`")  # noqa: E501

        self._competitive_price_id = competitive_price_id

    @property
    def price(self):
        """Gets the price of this CompetitivePriceType.  # noqa: E501


        :return: The price of this CompetitivePriceType.  # noqa: E501
        :rtype: PriceType
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this CompetitivePriceType.


        :param price: The price of this CompetitivePriceType.  # noqa: E501
        :type: PriceType
        """
        if price is None:
            raise ValueError("Invalid value for `price`, must not be `None`")  # noqa: E501

        self._price = price

    @property
    def condition(self):
        """Gets the condition of this CompetitivePriceType.  # noqa: E501

        Indicates the condition of the item whose pricing information is returned. Possible values are: New, Used, Collectible, Refurbished, or Club.  # noqa: E501

        :return: The condition of this CompetitivePriceType.  # noqa: E501
        :rtype: str
        """
        return self._condition

    @condition.setter
    def condition(self, condition):
        """Sets the condition of this CompetitivePriceType.

        Indicates the condition of the item whose pricing information is returned. Possible values are: New, Used, Collectible, Refurbished, or Club.  # noqa: E501

        :param condition: The condition of this CompetitivePriceType.  # noqa: E501
        :type: str
        """

        self._condition = condition

    @property
    def subcondition(self):
        """Gets the subcondition of this CompetitivePriceType.  # noqa: E501

        Indicates the subcondition of the item whose pricing information is returned. Possible values are: New, Mint, Very Good, Good, Acceptable, Poor, Club, OEM, Warranty, Refurbished Warranty, Refurbished, Open Box, or Other.  # noqa: E501

        :return: The subcondition of this CompetitivePriceType.  # noqa: E501
        :rtype: str
        """
        return self._subcondition

    @subcondition.setter
    def subcondition(self, subcondition):
        """Sets the subcondition of this CompetitivePriceType.

        Indicates the subcondition of the item whose pricing information is returned. Possible values are: New, Mint, Very Good, Good, Acceptable, Poor, Club, OEM, Warranty, Refurbished Warranty, Refurbished, Open Box, or Other.  # noqa: E501

        :param subcondition: The subcondition of this CompetitivePriceType.  # noqa: E501
        :type: str
        """

        self._subcondition = subcondition

    @property
    def belongs_to_requester(self):
        """Gets the belongs_to_requester of this CompetitivePriceType.  # noqa: E501

         Indicates whether or not the pricing information is for an offer listing that belongs to the requester. The requester is the seller associated with the SellerId that was submitted with the request. Possible values are: true and false.  # noqa: E501

        :return: The belongs_to_requester of this CompetitivePriceType.  # noqa: E501
        :rtype: bool
        """
        return self._belongs_to_requester

    @belongs_to_requester.setter
    def belongs_to_requester(self, belongs_to_requester):
        """Sets the belongs_to_requester of this CompetitivePriceType.

         Indicates whether or not the pricing information is for an offer listing that belongs to the requester. The requester is the seller associated with the SellerId that was submitted with the request. Possible values are: true and false.  # noqa: E501

        :param belongs_to_requester: The belongs_to_requester of this CompetitivePriceType.  # noqa: E501
        :type: bool
        """

        self._belongs_to_requester = belongs_to_requester

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CompetitivePriceType, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CompetitivePriceType):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Finances

    The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class RemovalShipmentItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'removal_shipment_item_id': 'str',
        'tax_collection_model': 'str',
        'fulfillment_network_sku': 'str',
        'quantity': 'int',
        'revenue': 'Currency',
        'fee_amount': 'Currency',
        'tax_amount': 'Currency',
        'tax_withheld': 'Currency'
    }

    attribute_map = {
        'removal_shipment_item_id': 'RemovalShipmentItemId',
        'tax_collection_model': 'TaxCollectionModel',
        'fulfillment_network_sku': 'FulfillmentNetworkSKU',
        'quantity': 'Quantity',
        'revenue': 'Revenue',
        'fee_amount': 'FeeAmount',
        'tax_amount': 'TaxAmount',
        'tax_withheld': 'TaxWithheld'
    }

    def __init__(self, removal_shipment_item_id=None, tax_collection_model=None, fulfillment_network_sku=None, quantity=None, revenue=None, fee_amount=None, tax_amount=None, tax_withheld=None):  # noqa: E501
        """RemovalShipmentItem - a model defined in Swagger"""  # noqa: E501
        self._removal_shipment_item_id = None
        self._tax_collection_model = None
        self._fulfillment_network_sku = None
        self._quantity = None
        self._revenue = None
        self._fee_amount = None
        self._tax_amount = None
        self._tax_withheld = None
        self.discriminator = None
        if removal_shipment_item_id is not None:
            self.removal_shipment_item_id = removal_shipment_item_id
        if tax_collection_model is not None:
            self.tax_collection_model = tax_collection_model
        if fulfillment_network_sku is not None:
            self.fulfillment_network_sku = fulfillment_network_sku
        if quantity is not None:
            self.quantity = quantity
        if revenue is not None:
            self.revenue = revenue
        if fee_amount is not None:
            self.fee_amount = fee_amount
        if tax_amount is not None:
            self.tax_amount = tax_amount
        if tax_withheld is not None:
            self.tax_withheld = tax_withheld

    @property
    def removal_shipment_item_id(self):
        """Gets the removal_shipment_item_id of this RemovalShipmentItem.  # noqa: E501

        An identifier for an item in a removal shipment.  # noqa: E501

        :return: The removal_shipment_item_id of this RemovalShipmentItem.  # noqa: E501
        :rtype: str
        """
        return self._removal_shipment_item_id

    @removal_shipment_item_id.setter
    def removal_shipment_item_id(self, removal_shipment_item_id):
        """Sets the removal_shipment_item_id of this RemovalShipmentItem.

        An identifier for an item in a removal shipment.  # noqa: E501

        :param removal_shipment_item_id: The removal_shipment_item_id of this RemovalShipmentItem.  # noqa: E501
        :type: str
        """

        self._removal_shipment_item_id = removal_shipment_item_id

    @property
    def tax_collection_model(self):
        """Gets the tax_collection_model of this RemovalShipmentItem.  # noqa: E501

        The tax collection model applied to the item.  Possible values:  * MarketplaceFacilitator - Tax is withheld and remitted to the taxing authority by Amazon on behalf of the seller.  * Standard - Tax is paid to the seller and not remitted to the taxing authority by Amazon.  # noqa: E501

        :return: The tax_collection_model of this RemovalShipmentItem.  # noqa: E501
        :rtype: str
        """
        return self._tax_collection_model

    @tax_collection_model.setter
    def tax_collection_model(self, tax_collection_model):
        """Sets the tax_collection_model of this RemovalShipmentItem.

        The tax collection model applied to the item.  Possible values:  * MarketplaceFacilitator - Tax is withheld and remitted to the taxing authority by Amazon on behalf of the seller.  * Standard - Tax is paid to the seller and not remitted to the taxing authority by Amazon.  # noqa: E501

        :param tax_collection_model: The tax_collection_model of this RemovalShipmentItem.  # noqa: E501
        :type: str
        """

        self._tax_collection_model = tax_collection_model

    @property
    def fulfillment_network_sku(self):
        """Gets the fulfillment_network_sku of this RemovalShipmentItem.  # noqa: E501

        The Amazon fulfillment network SKU for the item.  # noqa: E501

        :return: The fulfillment_network_sku of this RemovalShipmentItem.  # noqa: E501
        :rtype: str
        """
        return self._fulfillment_network_sku

    @fulfillment_network_sku.setter
    def fulfillment_network_sku(self, fulfillment_network_sku):
        """Sets the fulfillment_network_sku of this RemovalShipmentItem.

        The Amazon fulfillment network SKU for the item.  # noqa: E501

        :param fulfillment_network_sku: The fulfillment_network_sku of this RemovalShipmentItem.  # noqa: E501
        :type: str
        """

        self._fulfillment_network_sku = fulfillment_network_sku

    @property
    def quantity(self):
        """Gets the quantity of this RemovalShipmentItem.  # noqa: E501

        The quantity of the item.  # noqa: E501

        :return: The quantity of this RemovalShipmentItem.  # noqa: E501
        :rtype: int
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this RemovalShipmentItem.

        The quantity of the item.  # noqa: E501

        :param quantity: The quantity of this RemovalShipmentItem.  # noqa: E501
        :type: int
        """

        self._quantity = quantity

    @property
    def revenue(self):
        """Gets the revenue of this RemovalShipmentItem.  # noqa: E501


        :return: The revenue of this RemovalShipmentItem.  # noqa: E501
        :rtype: Currency
        """
        return self._revenue

    @revenue.setter
    def revenue(self, revenue):
        """Sets the revenue of this RemovalShipmentItem.


        :param revenue: The revenue of this RemovalShipmentItem.  # noqa: E501
        :type: Currency
        """

        self._revenue = revenue

    @property
    def fee_amount(self):
        """Gets the fee_amount of this RemovalShipmentItem.  # noqa: E501


        :return: The fee_amount of this RemovalShipmentItem.  # noqa: E501
        :rtype: Currency
        """
        return self._fee_amount

    @fee_amount.setter
    def fee_amount(self, fee_amount):
        """Sets the fee_amount of this RemovalShipmentItem.


        :param fee_amount: The fee_amount of this RemovalShipmentItem.  # noqa: E501
        :type: Currency
        """

        self._fee_amount = fee_amount

    @property
    def tax_amount(self):
        """Gets the tax_amount of this RemovalShipmentItem.  # noqa: E501


        :return: The tax_amount of this RemovalShipmentItem.  # noqa: E501
        :rtype: Currency
        """
        return self._tax_amount

    @tax_amount.setter
    def tax_amount(self, tax_amount):
        """Sets the tax_amount of this RemovalShipmentItem.


        :param tax_amount: The tax_amount of this RemovalShipmentItem.  # noqa: E501
        :type: Currency
        """

        self._tax_amount = tax_amount

    @property
    def tax_withheld(self):
        """Gets the tax_withheld of this RemovalShipmentItem.  # noqa: E501


        :return: The tax_withheld of this RemovalShipmentItem.  # noqa: E501
        :rtype: Currency
        """
        return self._tax_withheld

    @tax_withheld.setter
    def tax_withheld(self, tax_withheld):
        """Sets the tax_withheld of this RemovalShipmentItem.


        :param tax_withheld: The tax_withheld of this RemovalShipmentItem.  # noqa: E501
        :type: Currency
        """

        self._tax_withheld = tax_withheld

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RemovalShipmentItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RemovalShipmentItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Finances

    The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class TrialShipmentEvent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amazon_order_id': 'str',
        'financial_event_group_id': 'str',
        'posted_date': 'ModelDate',
        'sku': 'str',
        'fee_list': 'FeeComponentList'
    }

    attribute_map = {
        'amazon_order_id': 'AmazonOrderId',
        'financial_event_group_id': 'FinancialEventGroupId',
        'posted_date': 'PostedDate',
        'sku': 'SKU',
        'fee_list': 'FeeList'
    }

    def __init__(self, amazon_order_id=None, financial_event_group_id=None, posted_date=None, sku=None, fee_list=None):  # noqa: E501
        """TrialShipmentEvent - a model defined in Swagger"""  # noqa: E501
        self._amazon_order_id = None
        self._financial_event_group_id = None
        self._posted_date = None
        self._sku = None
        self._fee_list = None
        self.discriminator = None
        if amazon_order_id is not None:
            self.amazon_order_id = amazon_order_id
        if financial_event_group_id is not None:
            self.financial_event_group_id = financial_event_group_id
        if posted_date is not None:
            self.posted_date = posted_date
        if sku is not None:
            self.sku = sku
        if fee_list is not None:
            self.fee_list = fee_list

    @property
    def amazon_order_id(self):
        """Gets the amazon_order_id of this TrialShipmentEvent.  # noqa: E501

        An Amazon-defined identifier for an order.  # noqa: E501

        :return: The amazon_order_id of this TrialShipmentEvent.  # noqa: E501
        :rtype: str
        """
        return self._amazon_order_id

    @amazon_order_id.setter
    def amazon_order_id(self, amazon_order_id):
        """Sets the amazon_order_id of this TrialShipmentEvent.

        An Amazon-defined identifier for an order.  # noqa: E501

        :param amazon_order_id: The amazon_order_id of this TrialShipmentEvent.  # noqa: E501
        :type: str
        """

        self._amazon_order_id = amazon_order_id

    @property
    def financial_event_group_id(self):
        """Gets the financial_event_group_id of this TrialShipmentEvent.  # noqa: E501

        The identifier of the financial event group.  # noqa: E501

        :return: The financial_event_group_id of this TrialShipmentEvent.  # noqa: E501
        :rtype: str
        """
        return self._financial_event_group_id

    @financial_event_group_id.setter
    def financial_event_group_id(self, financial_event_group_id):
        """Sets the financial_event_group_id of this TrialShipmentEvent.

        The identifier of the financial event group.  # noqa: E501

        :param financial_event_group_id: The financial_event_group_id of this TrialShipmentEvent.  # noqa: E501
        :type: str
        """

        self._financial_event_group_id = financial_event_group_id

    @property
    def posted_date(self):
        """Gets the posted_date of this TrialShipmentEvent.  # noqa: E501


        :return: The posted_date of this TrialShipmentEvent.  # noqa: E501
        :rtype: ModelDate
        """
        return self._posted_date

    @posted_date.setter
    def posted_date(self, posted_date):
        """Sets the posted_date of this TrialShipmentEvent.


        :param posted_date: The posted_date of this TrialShipmentEvent.  # noqa: E501
        :type: ModelDate
        """

        self._posted_date = posted_date

    @property
    def sku(self):
        """Gets the sku of this TrialShipmentEvent.  # noqa: E501

        The seller SKU of the item. The seller SKU is qualified by the seller's seller ID, which is included with every call to the Selling Partner API.  # noqa: E501

        :return: The sku of this TrialShipmentEvent.  # noqa: E501
        :rtype: str
        """
        return self._sku

    @sku.setter
    def sku(self, sku):
        """Sets the sku of this TrialShipmentEvent.

        The seller SKU of the item. The seller SKU is qualified by the seller's seller ID, which is included with every call to the Selling Partner API.  # noqa: E501

        :param sku: The sku of this TrialShipmentEvent.  # noqa: E501
        :type: str
        """

        self._sku = sku

    @property
    def fee_list(self):
        """Gets the fee_list of this TrialShipmentEvent.  # noqa: E501


        :return: The fee_list of this TrialShipmentEvent.  # noqa: E501
        :rtype: FeeComponentList
        """
        return self._fee_list

    @fee_list.setter
    def fee_list(self, fee_list):
        """Sets the fee_list of this TrialShipmentEvent.


        :param fee_list: The fee_list of this TrialShipmentEvent.  # noqa: E501
        :type: FeeComponentList
        """

        self._fee_list = fee_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TrialShipmentEvent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TrialShipmentEvent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Finances

    The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class SellerDealPaymentEvent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'posted_date': 'ModelDate',
        'deal_id': 'str',
        'deal_description': 'str',
        'event_type': 'str',
        'fee_type': 'str',
        'fee_amount': 'Currency',
        'tax_amount': 'Currency',
        'total_amount': 'Currency'
    }

    attribute_map = {
        'posted_date': 'postedDate',
        'deal_id': 'dealId',
        'deal_description': 'dealDescription',
        'event_type': 'eventType',
        'fee_type': 'feeType',
        'fee_amount': 'feeAmount',
        'tax_amount': 'taxAmount',
        'total_amount': 'totalAmount'
    }

    def __init__(self, posted_date=None, deal_id=None, deal_description=None, event_type=None, fee_type=None, fee_amount=None, tax_amount=None, total_amount=None):  # noqa: E501
        """SellerDealPaymentEvent - a model defined in Swagger"""  # noqa: E501
        self._posted_date = None
        self._deal_id = None
        self._deal_description = None
        self._event_type = None
        self._fee_type = None
        self._fee_amount = None
        self._tax_amount = None
        self._total_amount = None
        self.discriminator = None
        if posted_date is not None:
            self.posted_date = posted_date
        if deal_id is not None:
            self.deal_id = deal_id
        if deal_description is not None:
            self.deal_description = deal_description
        if event_type is not None:
            self.event_type = event_type
        if fee_type is not None:
            self.fee_type = fee_type
        if fee_amount is not None:
            self.fee_amount = fee_amount
        if tax_amount is not None:
            self.tax_amount = tax_amount
        if total_amount is not None:
            self.total_amount = total_amount

    @property
    def posted_date(self):
        """Gets the posted_date of this SellerDealPaymentEvent.  # noqa: E501


        :return: The posted_date of this SellerDealPaymentEvent.  # noqa: E501
        :rtype: ModelDate
        """
        return self._posted_date

    @posted_date.setter
    def posted_date(self, posted_date):
        """Sets the posted_date of this SellerDealPaymentEvent.


        :param posted_date: The posted_date of this SellerDealPaymentEvent.  # noqa: E501
        :type: ModelDate
        """

        self._posted_date = posted_date

    @property
    def deal_id(self):
        """Gets the deal_id of this SellerDealPaymentEvent.  # noqa: E501

        The unique identifier of the deal.  # noqa: E501

        :return: The deal_id of this SellerDealPaymentEvent.  # noqa: E501
        :rtype: str
        """
        return self._deal_id

    @deal_id.setter
    def deal_id(self, deal_id):
        """Sets the deal_id of this SellerDealPaymentEvent.

        The unique identifier of the deal.  # noqa: E501

        :param deal_id: The deal_id of this SellerDealPaymentEvent.  # noqa: E501
        :type: str
        """

        self._deal_id = deal_id

    @property
    def deal_description(self):
        """Gets the deal_description of this SellerDealPaymentEvent.  # noqa: E501

        The internal description of the deal.  # noqa: E501

        :return: The deal_description of this SellerDealPaymentEvent.  # noqa: E501
        :rtype: str
        """
        return self._deal_description

    @deal_description.setter
    def deal_description(self, deal_description):
        """Sets the deal_description of this SellerDealPaymentEvent.

        The internal description of the deal.  # noqa: E501

        :param deal_description: The deal_description of this SellerDealPaymentEvent.  # noqa: E501
        :type: str
        """

        self._deal_description = deal_description

    @property
    def event_type(self):
        """Gets the event_type of this SellerDealPaymentEvent.  # noqa: E501

        The type of event: SellerDealComplete.  # noqa: E501

        :return: The event_type of this SellerDealPaymentEvent.  # noqa: E501
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this SellerDealPaymentEvent.

        The type of event: SellerDealComplete.  # noqa: E501

        :param event_type: The event_type of this SellerDealPaymentEvent.  # noqa: E501
        :type: str
        """

        self._event_type = event_type

    @property
    def fee_type(self):
        """Gets the fee_type of this SellerDealPaymentEvent.  # noqa: E501

        The type of fee: RunLightningDealFee.  # noqa: E501

        :return: The fee_type of this SellerDealPaymentEvent.  # noqa: E501
        :rtype: str
        """
        return self._fee_type

    @fee_type.setter
    def fee_type(self, fee_type):
        """Sets the fee_type of this SellerDealPaymentEvent.

        The type of fee: RunLightningDealFee.  # noqa: E501

        :param fee_type: The fee_type of this SellerDealPaymentEvent.  # noqa: E501
        :type: str
        """

        self._fee_type = fee_type

    @property
    def fee_amount(self):
        """Gets the fee_amount of this SellerDealPaymentEvent.  # noqa: E501


        :return: The fee_amount of this SellerDealPaymentEvent.  # noqa: E501
        :rtype: Currency
        """
        return self._fee_amount

    @fee_amount.setter
    def fee_amount(self, fee_amount):
        """Sets the fee_amount of this SellerDealPaymentEvent.


        :param fee_amount: The fee_amount of this SellerDealPaymentEvent.  # noqa: E501
        :type: Currency
        """

        self._fee_amount = fee_amount

    @property
    def tax_amount(self):
        """Gets the tax_amount of this SellerDealPaymentEvent.  # noqa: E501


        :return: The tax_amount of this SellerDealPaymentEvent.  # noqa: E501
        :rtype: Currency
        """
        return self._tax_amount

    @tax_amount.setter
    def tax_amount(self, tax_amount):
        """Sets the tax_amount of this SellerDealPaymentEvent.


        :param tax_amount: The tax_amount of this SellerDealPaymentEvent.  # noqa: E501
        :type: Currency
        """

        self._tax_amount = tax_amount

    @property
    def total_amount(self):
        """Gets the total_amount of this SellerDealPaymentEvent.  # noqa: E501


        :return: The total_amount of this SellerDealPaymentEvent.  # noqa: E501
        :rtype: Currency
        """
        return self._total_amount

    @total_amount.setter
    def total_amount(self, total_amount):
        """Sets the total_amount of this SellerDealPaymentEvent.


        :param total_amount: The total_amount of this SellerDealPaymentEvent.  # noqa: E501
        :type: Currency
        """

        self._total_amount = total_amount

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SellerDealPaymentEvent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SellerDealPaymentEvent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Orders

    The Selling Partner API for Orders helps you programmatically retrieve order information. These APIs let you develop fast, flexible, custom applications in areas like order synchronization, order research, and demand-based decision support tools.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Address(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'address_line1': 'str',
        'address_line2': 'str',
        'address_line3': 'str',
        'city': 'str',
        'county': 'str',
        'district': 'str',
        'state_or_region': 'str',
        'municipality': 'str',
        'postal_code': 'str',
        'country_code': 'str',
        'phone': 'str',
        'address_type': 'str'
    }

    attribute_map = {
        'name': 'Name',
        'address_line1': 'AddressLine1',
        'address_line2': 'AddressLine2',
        'address_line3': 'AddressLine3',
        'city': 'City',
        'county': 'County',
        'district': 'District',
        'state_or_region': 'StateOrRegion',
        'municipality': 'Municipality',
        'postal_code': 'PostalCode',
        'country_code': 'CountryCode',
        'phone': 'Phone',
        'address_type': 'AddressType'
    }

    def __init__(self, name=None, address_line1=None, address_line2=None, address_line3=None, city=None, county=None, district=None, state_or_region=None, municipality=None, postal_code=None, country_code=None, phone=None, address_type=None):  # noqa: E501
        """Address - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._address_line1 = None
        self._address_line2 = None
        self._address_line3 = None
        self._city = None
        self._county = None
        self._district = None
        self._state_or_region = None
        self._municipality = None
        self._postal_code = None
        self._country_code = None
        self._phone = None
        self._address_type = None
        self.discriminator = None
        self.name = name
        if address_line1 is not None:
            self.address_line1 = address_line1
        if address_line2 is not None:
            self.address_line2 = address_line2
        if address_line3 is not None:
            self.address_line3 = address_line3
        if city is not None:
            self.city = city
        if county is not None:
            self.county = county
        if district is not None:
            self.district = district
        if state_or_region is not None:
            self.state_or_region = state_or_region
        if municipality is not None:
            self.municipality = municipality
        if postal_code is not None:
            self.postal_code = postal_code
        if country_code is not None:
            self.country_code = country_code
        if phone is not None:
            self.phone = phone
        if address_type is not None:
            self.address_type = address_type

    @property
    def name(self):
        """Gets the name of this Address.  # noqa: E501

        The name.  # noqa: E501

        :return: The name of this Address.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Address.

        The name.  # noqa: E501

        :param name: The name of this Address.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def address_line1(self):
        """Gets the address_line1 of this Address.  # noqa: E501

        The street address.  # noqa: E501

        :return: The address_line1 of this Address.  # noqa: E501
        :rtype: str
        """
        return self._address_line1

    @address_line1.setter
    def address_line1(self, address_line1):
        """Sets the address_line1 of this Address.

        The street address.  # noqa: E501

        :param address_line1: The address_line1 of this Address.  # noqa: E501
        :type: str
        """

        self._address_line1 = address_line1

    @property
    def address_line2(self):
        """Gets the address_line2 of this Address.  # noqa: E501

        Additional street address information, if required.  # noqa: E501

        :return: The address_line2 of this Address.  # noqa: E501
        :rtype: str
        """
        return self._address_line2

    @address_line2.setter
    def address_line2(self, address_line2):
        """Sets the address_line2 of this Address.

        Additional street address information, if required.  # noqa: E501

        :param address_line2: The address_line2 of this Address.  # noqa: E501
        :type: str
        """

        self._address_line2 = address_line2

    @property
    def address_line3(self):
        """Gets the address_line3 of this Address.  # noqa: E501

        Additional street address information, if required.  # noqa: E501

        :return: The address_line3 of this Address.  # noqa: E501
        :rtype: str
        """
        return self._address_line3

    @address_line3.setter
    def address_line3(self, address_line3):
        """Sets the address_line3 of this Address.

        Additional street address information, if required.  # noqa: E501

        :param address_line3: The address_line3 of this Address.  # noqa: E501
        :type: str
        """

        self._address_line3 = address_line3

    @property
    def city(self):
        """Gets the city of this Address.  # noqa: E501

        The city   # noqa: E501

        :return: The city of this Address.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this Address.

        The city   # noqa: E501

        :param city: The city of this Address.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def county(self):
        """Gets the county of this Address.  # noqa: E501

        The county.  # noqa: E501

        :return: The county of this Address.  # noqa: E501
        :rtype: str
        """
        return self._county

    @county.setter
    def county(self, county):
        """Sets the county of this Address.

        The county.  # noqa: E501

        :param county: The county of this Address.  # noqa: E501
        :type: str
        """

        self._county = county

    @property
    def district(self):
        """Gets the district of this Address.  # noqa: E501

        The district.  # noqa: E501

        :return: The district of this Address.  # noqa: E501
        :rtype: str
        """
        return self._district

    @district.setter
    def district(self, district):
        """Sets the district of this Address.

        The district.  # noqa: E501

        :param district: The district of this Address.  # noqa: E501
        :type: str
        """

        self._district = district

    @property
    def state_or_region(self):
        """Gets the state_or_region of this Address.  # noqa: E501

        The state or region.  # noqa: E501

        :return: The state_or_region of this Address.  # noqa: E501
        :rtype: str
        """
        return self._state_or_region

    @state_or_region.setter
    def state_or_region(self, state_or_region):
        """Sets the state_or_region of this Address.

        The state or region.  # noqa: E501

        :param state_or_region: The state_or_region of this Address.  # noqa: E501
        :type: str
        """

        self._state_or_region = state_or_region

    @property
    def municipality(self):
        """Gets the municipality of this Address.  # noqa: E501

        The municipality.  # noqa: E501

        :return: The municipality of this Address.  # noqa: E501
        :rtype: str
        """
        return self._municipality

    @municipality.setter
    def municipality(self, municipality):
        """Sets the municipality of this Address.

        The municipality.  # noqa: E501

        :param municipality: The municipality of this Address.  # noqa: E501
        :type: str
        """

        self._municipality = municipality

    @property
    def postal_code(self):
        """Gets the postal_code of this Address.  # noqa: E501

        The postal code.  # noqa: E501

        :return: The postal_code of this Address.  # noqa: E501
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """Sets the postal_code of this Address.

        The postal code.  # noqa: E501

        :param postal_code: The postal_code of this Address.  # noqa: E501
        :type: str
        """

        self._postal_code = postal_code

    @property
    def country_code(self):
        """Gets the country_code of this Address.  # noqa: E501

        The country code. A two-character country code, in ISO 3166-1 alpha-2 format.  # noqa: E501

        :return: The country_code of this Address.  # noqa: E501
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """Sets the country_code of this Address.

        The country code. A two-character country code, in ISO 3166-1 alpha-2 format.  # noqa: E501

        :param country_code: The country_code of this Address.  # noqa: E501
        :type: str
        """

        self._country_code = country_code

    @property
    def phone(self):
        """Gets the phone of this Address.  # noqa: E501

        The phone number. Not returned for Fulfillment by Amazon (FBA) orders.  # noqa: E501

        :return: The phone of this Address.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this Address.

        The phone number. Not returned for Fulfillment by Amazon (FBA) orders.  # noqa: E501

        :param phone: The phone of this Address.  # noqa: E501
        :type: str
        """

        self._phone = phone

    @property
    def address_type(self):
        """Gets the address_type of this Address.  # noqa: E501

        The address type of the shipping address.  # noqa: E501

        :return: The address_type of this Address.  # noqa: E501
        :rtype: str
        """
        return self._address_type

    @address_type.setter
    def address_type(self, address_type):
        """Sets the address_type of this Address.

        The address type of the shipping address.  # noqa: E501

        :param address_type: The address_type of this Address.  # noqa: E501
        :type: str
        """
        allowed_values = ["Residential", "Commercial"]  # noqa: E501
        if address_type not in allowed_values:
            raise ValueError(
                "Invalid value for `address_type` ({0}), must be one of {1}"  # noqa: E501
                .format(address_type, allowed_values)
            )

        self._address_type = address_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Address, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Address):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Reports

    The Selling Partner API for Reports lets you retrieve and manage a variety of reports that can help selling partners manage their businesses.  # noqa: E501

    OpenAPI spec version: 2020-09-04
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class CreateReportSpecification(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'report_options': 'ReportOptions',
        'report_type': 'str',
        'data_start_time': 'datetime',
        'data_end_time': 'datetime',
        'marketplace_ids': 'list[str]'
    }

    attribute_map = {
        'report_options': 'reportOptions',
        'report_type': 'reportType',
        'data_start_time': 'dataStartTime',
        'data_end_time': 'dataEndTime',
        'marketplace_ids': 'marketplaceIds'
    }

    def __init__(self, report_options=None, report_type=None, data_start_time=None, data_end_time=None, marketplace_ids=None):  # noqa: E501
        """CreateReportSpecification - a model defined in Swagger"""  # noqa: E501
        self._report_options = None
        self._report_type = None
        self._data_start_time = None
        self._data_end_time = None
        self._marketplace_ids = None
        self.discriminator = None
        if report_options is not None:
            self.report_options = report_options
        self.report_type = report_type
        if data_start_time is not None:
            self.data_start_time = data_start_time
        if data_end_time is not None:
            self.data_end_time = data_end_time
        self.marketplace_ids = marketplace_ids

    @property
    def report_options(self):
        """Gets the report_options of this CreateReportSpecification.  # noqa: E501


        :return: The report_options of this CreateReportSpecification.  # noqa: E501
        :rtype: ReportOptions
        """
        return self._report_options

    @report_options.setter
    def report_options(self, report_options):
        """Sets the report_options of this CreateReportSpecification.


        :param report_options: The report_options of this CreateReportSpecification.  # noqa: E501
        :type: ReportOptions
        """

        self._report_options = report_options

    @property
    def report_type(self):
        """Gets the report_type of this CreateReportSpecification.  # noqa: E501

        The report type.  # noqa: E501

        :return: The report_type of this CreateReportSpecification.  # noqa: E501
        :rtype: str
        """
        return self._report_type

    @report_type.setter
    def report_type(self, report_type):
        """Sets the report_type of this CreateReportSpecification.

        The report type.  # noqa: E501

        :param report_type: The report_type of this CreateReportSpecification.  # noqa: E501
        :type: str
        """
        if report_type is None:
            raise ValueError("Invalid value for `report_type`, must not be `None`")  # noqa: E501

        self._report_type = report_type

    @property
    def data_start_time(self):
        """Gets the data_start_time of this CreateReportSpecification.  # noqa: E501

        The start of a date and time range, in ISO 8601 date time format, used for selecting the data to report. The default is now. The value must be prior to or equal to the current date and time. Not all report types make use of this.  # noqa: E501

        :return: The data_start_time of this CreateReportSpecification.  # noqa: E501
        :rtype: datetime
        """
        return self._data_start_time

    @data_start_time.setter
    def data_start_time(self, data_start_time):
        """Sets the data_start_time of this CreateReportSpecification.

        The start of a date and time range, in ISO 8601 date time format, used for selecting the data to report. The default is now. The value must be prior to or equal to the current date and time. Not all report types make use of this.  # noqa: E501

        :param data_start_time: The data_start_time of this CreateReportSpecification.  # noqa: E501
        :type: datetime
        """

        self._data_start_time = data_start_time

    @property
    def data_end_time(self):
        """Gets the data_end_time of this CreateReportSpecification.  # noqa: E501

        The end of a date and time range, in ISO 8601 date time format, used for selecting the data to report. The default is now. The value must be prior to or equal to the current date and time. Not all report types make use of this.  # noqa: E501

        :return: The data_end_time of this CreateReportSpecification.  # noqa: E501
        :rtype: datetime
        """
        return self._data_end_time

    @data_end_time.setter
    def data_end_time(self, data_end_time):
        """Sets the data_end_time of this CreateReportSpecification.

        The end of a date and time range, in ISO 8601 date time format, used for selecting the data to report. The default is now. The value must be prior to or equal to the current date and time. Not all report types make use of this.  # noqa: E501

        :param data_end_time: The data_end_time of this CreateReportSpecification.  # noqa: E501
        :type: datetime
        """

        self._data_end_time = data_end_time

    @property
    def marketplace_ids(self):
        """Gets the marketplace_ids of this CreateReportSpecification.  # noqa: E501

        A list of marketplace identifiers. The report document's contents will contain data for all of the specified marketplaces, unless the report type indicates otherwise.  # noqa: E501

        :return: The marketplace_ids of this CreateReportSpecification.  # noqa: E501
        :rtype: list[str]
        """
        return self._marketplace_ids

    @marketplace_ids.setter
    def marketplace_ids(self, marketplace_ids):
        """Sets the marketplace_ids of this CreateReportSpecification.

        A list of marketplace identifiers. The report document's contents will contain data for all of the specified marketplaces, unless the report type indicates otherwise.  # noqa: E501

        :param marketplace_ids: The marketplace_ids of this CreateReportSpecification.  # noqa: E501
        :type: list[str]
        """
        if marketplace_ids is None:
            raise ValueError("Invalid value for `marketplace_ids`, must not be `None`")  # noqa: E501

        self._marketplace_ids = marketplace_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateReportSpecification, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateReportSpecification):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Product Fees

    The Selling Partner API for Product Fees lets you programmatically retrieve estimated fees for a product. You can then account for those fees in your pricing.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class PriceToEstimateFees(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'listing_price': 'MoneyType',
        'shipping': 'MoneyType',
        'points': 'Points'
    }

    attribute_map = {
        'listing_price': 'ListingPrice',
        'shipping': 'Shipping',
        'points': 'Points'
    }

    def __init__(self, listing_price=None, shipping=None, points=None):  # noqa: E501
        """PriceToEstimateFees - a model defined in Swagger"""  # noqa: E501
        self._listing_price = None
        self._shipping = None
        self._points = None
        self.discriminator = None
        self.listing_price = listing_price
        if shipping is not None:
            self.shipping = shipping
        if points is not None:
            self.points = points

    @property
    def listing_price(self):
        """Gets the listing_price of this PriceToEstimateFees.  # noqa: E501


        :return: The listing_price of this PriceToEstimateFees.  # noqa: E501
        :rtype: MoneyType
        """
        return self._listing_price

    @listing_price.setter
    def listing_price(self, listing_price):
        """Sets the listing_price of this PriceToEstimateFees.


        :param listing_price: The listing_price of this PriceToEstimateFees.  # noqa: E501
        :type: MoneyType
        """
        if listing_price is None:
            raise ValueError("Invalid value for `listing_price`, must not be `None`")  # noqa: E501

        self._listing_price = listing_price

    @property
    def shipping(self):
        """Gets the shipping of this PriceToEstimateFees.  # noqa: E501


        :return: The shipping of this PriceToEstimateFees.  # noqa: E501
        :rtype: MoneyType
        """
        return self._shipping

    @shipping.setter
    def shipping(self, shipping):
        """Sets the shipping of this PriceToEstimateFees.


        :param shipping: The shipping of this PriceToEstimateFees.  # noqa: E501
        :type: MoneyType
        """

        self._shipping = shipping

    @property
    def points(self):
        """Gets the points of this PriceToEstimateFees.  # noqa: E501


        :return: The points of this PriceToEstimateFees.  # noqa: E501
        :rtype: Points
        """
        return self._points

    @points.setter
    def points(self, points):
        """Sets the points of this PriceToEstimateFees.


        :param points: The points of this PriceToEstimateFees.  # noqa: E501
        :type: Points
        """

        self._points = points

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PriceToEstimateFees, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PriceToEstimateFees):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Selling Partner API for Notifications

    The Selling Partner API for Notifications lets you subscribe to notifications that are relevant to a selling partner's business. Using this API you can create a destination to receive notifications, subscribe to notifications, delete notification subscriptions, and more.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from models.create_subscription_request import CreateSubscriptionRequest  # noqa: E501
from swagger_client.rest import ApiException


class TestCreateSubscriptionRequest(unittest.TestCase):
    """CreateSubscriptionRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateSubscriptionRequest(self):
        """Test CreateSubscriptionRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.create_subscription_request.CreateSubscriptionRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Selling Partner API for Finances

    The Selling Partner API for Finances helps you obtain financial information relevant to a seller's business. You can obtain financial events for a given order, financial event group, or date range without having to wait until a statement period closes. You can also obtain financial event groups for a given date range.  # noqa: E501

    OpenAPI spec version: v0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class DebtRecoveryItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'recovery_amount': 'Currency',
        'original_amount': 'Currency',
        'group_begin_date': 'ModelDate',
        'group_end_date': 'ModelDate'
    }

    attribute_map = {
        'recovery_amount': 'RecoveryAmount',
        'original_amount': 'OriginalAmount',
        'group_begin_date': 'GroupBeginDate',
        'group_end_date': 'GroupEndDate'
    }

    def __init__(self, recovery_amount=None, original_amount=None, group_begin_date=None, group_end_date=None):  # noqa: E501
        """DebtRecoveryItem - a model defined in Swagger"""  # noqa: E501
        self._recovery_amount = None
        self._original_amount = None
        self._group_begin_date = None
        self._group_end_date = None
        self.discriminator = None
        if recovery_amount is not None:
            self.recovery_amount = recovery_amount
        if original_amount is not None:
            self.original_amount = original_amount
        if group_begin_date is not None:
            self.group_begin_date = group_begin_date
        if group_end_date is not None:
            self.group_end_date = group_end_date

    @property
    def recovery_amount(self):
        """Gets the recovery_amount of this DebtRecoveryItem.  # noqa: E501


        :return: The recovery_amount of this DebtRecoveryItem.  # noqa: E501
        :rtype: Currency
        """
        return self._recovery_amount

    @recovery_amount.setter
    def recovery_amount(self, recovery_amount):
        """Sets the recovery_amount of this DebtRecoveryItem.


        :param recovery_amount: The recovery_amount of this DebtRecoveryItem.  # noqa: E501
        :type: Currency
        """

        self._recovery_amount = recovery_amount

    @property
    def original_amount(self):
        """Gets the original_amount of this DebtRecoveryItem.  # noqa: E501


        :return: The original_amount of this DebtRecoveryItem.  # noqa: E501
        :rtype: Currency
        """
        return self._original_amount

    @original_amount.setter
    def original_amount(self, original_amount):
        """Sets the original_amount of this DebtRecoveryItem.


        :param original_amount: The original_amount of this DebtRecoveryItem.  # noqa: E501
        :type: Currency
        """

        self._original_amount = original_amount

    @property
    def group_begin_date(self):
        """Gets the group_begin_date of this DebtRecoveryItem.  # noqa: E501


        :return: The group_begin_date of this DebtRecoveryItem.  # noqa: E501
        :rtype: ModelDate
        """
        return self._group_begin_date

    @group_begin_date.setter
    def group_begin_date(self, group_begin_date):
        """Sets the group_begin_date of this DebtRecoveryItem.


        :param group_begin_date: The group_begin_date of this DebtRecoveryItem.  # noqa: E501
        :type: ModelDate
        """

        self._group_begin_date = group_begin_date

    @property
    def group_end_date(self):
        """Gets the group_end_date of this DebtRecoveryItem.  # noqa: E501


        :return: The group_end_date of this DebtRecoveryItem.  # noqa: E501
        :rtype: ModelDate
        """
        return self._group_end_date

    @group_end_date.setter
    def group_end_date(self, group_end_date):
        """Sets the group_end_date of this DebtRecoveryItem.


        :param group_end_date: The group_end_date of this DebtRecoveryItem.  # noqa: E501
        :type: ModelDate
        """

        self._group_end_date = group_end_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DebtRecoveryItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DebtRecoveryItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
